@@ -218,6 +218,8 @@ USAGE: ${PROGRAM} [options]
   --internal-systemd-journal Enable the internal journal file reader instead of using libsystemd
   --enable-plugin-otel Enable the Netdata OpenTelemetry plugin. Default: disabled
   --disable-plugin-otel Explicitly disable the Netdata OpenTelemetry plugin.
+  --enable-plugin-ibm        Enable the IBM ecosystem monitoring plugin. Default: disabled
+  --disable-plugin-ibm       Explicitly disable the IBM ecosystem monitoring plugin.
   --enable-exporting-kinesis Enable AWS Kinesis exporting connector. Default: enable it when libaws_cpp_sdk_kinesis
                              and its dependencies are available.
   --disable-exporting-kinesis Explicitly disable AWS Kinesis exporting connector.
@@ -260,6 +262,7 @@ ENABLE_GO=1
 ENABLE_PYTHON=1
 ENABLE_CHARTS=1
 ENABLE_OTEL=0
+ENABLE_IBM=0
 FORCE_LEGACY_CXX=0
 NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS-}"
 REMOVE_BUILD=1
@@ -301,6 +304,8 @@ while [ -n "${1}" ]; do
     "--internal-systemd-journal") USE_RUST_JOURNAL_FILE=1 ;;
     "--enable-plugin-otel") ENABLE_OTEL=1 ;;
     "--disable-plugin-otel") ENABLE_OTEL=0 ;;
+    "--enable-plugin-ibm") ENABLE_IBM=1 ;;
+    "--disable-plugin-ibm") ENABLE_IBM=0 ;;
     "--enable-exporting-kinesis" | "--enable-backend-kinesis")
       # TODO: Needs CMake Support
       ;;
@@ -555,6 +560,21 @@ if [ "${ENABLE_GO}" -eq 1 ]; then
   fi
 fi
 
+# -----------------------------------------------------------------------------
+# If we're installing the IBM plugin, ensure CGO is available
+if [ "${ENABLE_IBM}" -eq 1 ]; then
+  if [ "${ENABLE_GO}" -eq 0 ]; then
+    warning "IBM plugin requires Go plugin to be enabled. Disabling IBM plugin."
+    ENABLE_IBM=0
+  else
+    # Check for a C compiler for CGO
+    if ! command -v gcc >/dev/null 2>&1 && ! command -v clang >/dev/null 2>&1; then
+      warning "IBM plugin requires a C compiler (gcc or clang) for CGO. Disabling IBM plugin."
+      ENABLE_IBM=0
+    fi
+  fi
+fi
+
 # -----------------------------------------------------------------------------
 # If we have the dashboard switching logic, make sure we're on the classic
 # dashboard during the install (updates don't work correctly otherwise).
@@ -660,25 +680,9 @@ fi
 # -----------------------------------------------------------------------------
 progress "Creating standard user and groups for netdata"
 
-NETDATA_WANTED_GROUPS="docker nginx varnish haproxy adm nsd proxy squid ceph nobody"
 NETDATA_ADDED_TO_GROUPS=""
 if [ "$(id -u)" -eq 0 ]; then
-  progress "Adding group 'netdata'"
-  portable_add_group netdata || :
-
-  progress "Adding user 'netdata'"
-  portable_add_user netdata "${NETDATA_PREFIX}/var/lib/netdata" || :
-
-  progress "Assign user 'netdata' to required groups"
-  for g in ${NETDATA_WANTED_GROUPS}; do
-    # shellcheck disable=SC2086
-    portable_add_user_to_group ${g} netdata && NETDATA_ADDED_TO_GROUPS="${NETDATA_ADDED_TO_GROUPS} ${g}"
-  done
-  # Netdata must be able to read /etc/pve/qemu-server/* and /etc/pve/lxc/*
-  # for reading VMs/containers names, CPU and memory limits on Proxmox.
-  if [ -d "/etc/pve" ]; then
-    portable_add_user_to_group "www-data" netdata && NETDATA_ADDED_TO_GROUPS="${NETDATA_ADDED_TO_GROUPS} www-data"
-  fi
+  create_netdata_accounts
 else
   run_failed "The installer does not run as root. Nothing to do for user and groups"
 fi
