@@ -299,9 +299,9 @@ prepare_cmake_options() {
 
   if [ -n "${NETDATA_ENABLE_LTO}" ]; then
     if [ "${NETDATA_ENABLE_LTO}" -eq 1 ]; then
-      NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS} -DDISABLE_LTO=Off"
+      NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS} -DCMAKE_INTERPROCEDURAL_OPTIMIZATION=On -DUSE_LTO=On"
     else
-      NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS} -DDISABLE_LTO=On"
+      NETDATA_CMAKE_OPTIONS="${NETDATA_CMAKE_OPTIONS} -DCMAKE_INTERPROCEDURAL_OPTIMIZATION=Off -DUSE_LTO=Off"
     fi
   fi
 
@@ -378,6 +378,7 @@ prepare_cmake_options() {
   enable_feature ML "${NETDATA_ENABLE_ML:-1}"
   enable_feature PLUGIN_APPS "${ENABLE_APPS:-1}"
   enable_feature PLUGIN_OTEL "${ENABLE_OTEL:-0}"
+  enable_feature PLUGIN_IBM "${ENABLE_IBM:-0}"
 
   check_for_feature EXPORTER_PROMETHEUS_REMOTE_WRITE "${EXPORTER_PROMETHEUS}" snappy
   check_for_feature EXPORTER_MONGODB "${EXPORTER_MONGODB}" libmongoc-1.0
@@ -1035,6 +1036,30 @@ EOF
 
 }
 
+# -----------------------------------------------------------------------------
+# user handling functions
+
+create_netdata_accounts() {
+  NETDATA_WANTED_GROUPS="docker ceph I2C"
+
+  if [ -d "/etc/pve" ]; then
+    NETDATA_WANTED_GROUPS="${NETDATA_WANTED_GROUPS} www-data"
+  fi
+
+  if command -v systemd-sysusers >/dev/null 2>&1; then
+    install -m 644 -o root -g root "${NETDATA_PREFIX}/usr/lib/netdata/system/systemd/sysusers/netdata.conf" /usr/lib/sysusers.d/netdata.conf
+    systemd-sysusers /usr/lib/sysusers.d/netdata.conf
+  else
+    portable_add_group netdata || :
+    portable_add_user netdata "${NETDATA_PREFIX}/var/lib/netdata" || :
+  fi
+
+  for g in ${NETDATA_WANTED_GROUPS}; do
+    # shellcheck disable=SC2086
+    portable_add_user_to_group ${g} netdata && NETDATA_ADDED_TO_GROUPS="${NETDATA_ADDED_TO_GROUPS:-} ${g}"
+  done
+}
+
 portable_add_user() {
   username="${1}"
   homedir="${2}"
