@@ -1,7 +1,7 @@
 #ifndef ACLK_PROXY_H
 #define ACLK_PROXY_H
 
-#include <config.h>
+#include "aclk.h"
 
 #define ACLK_PROXY_PROTO_ADDR_SEPARATOR "://"
 
@@ -16,6 +16,6 @@ typedef enum aclk_proxy_type {
 ACLK_PROXY_TYPE aclk_verify_proxy(const char *string);
 const char *aclk_lws_wss_get_proxy_setting(ACLK_PROXY_TYPE *type);
 void safe_log_proxy_censor(char *proxy);
-const char *aclk_get_proxy(ACLK_PROXY_TYPE *type);
+const char *aclk_get_proxy(ACLK_PROXY_TYPE *type, bool for_logging);
 
 #endif /* ACLK_PROXY_H */
