@@ -454,6 +454,22 @@
 
 // Sensors
 #define NETDATA_CHART_PRIO_SENSORS                   70000 // many charts
+#define NETDATA_CHART_PRIO_SENSOR_CURRENT            70003
+#define NETDATA_CHART_PRIO_SENSOR_HUMIDITY           70004
+#define NETDATA_CHART_PRIO_SENSOR_POWER              70006
+#define NETDATA_CHART_PRIO_SENSOR_LUX                70010
+#define NETDATA_CHART_PRIO_SENSOR_TEMPERATURE        70011
+#define NETDATA_CHART_PRIO_SENSOR_VOLTAGE            70012
+#define NETDATA_CHART_PRIO_SENSOR_RESISTENCE         70013
+#define NETDATA_CHART_PRIO_SENSOR_AMBIENT_PRESSURE   70014
+#define NETDATA_CHART_PRIO_SENSOR_LATITUDE           70015
+#define NETDATA_CHART_PRIO_SENSOR_LONGITUDE          70016
+#define NETDATA_CHART_PRIO_SENSOR_FORCE              70017
+#define NETDATA_CHART_PRIO_SENSOR_GAUGE_PRESSURE     70018
+#define NETDATA_CHART_PRIO_SENSOR_DISTANCE           70019
+#define NETDATA_CHART_PRIO_SENSOR_ACCELERATION       70022
+#define NETDATA_CHART_PRIO_SENSOR_MIN_CUSTOM         70100 // Windows only
+#define NETDATA_CHART_PRIO_SENSOR_MAX_CUSTOM         70128 // Windows only
 
 // STATSD
 
