@@ -93,6 +93,67 @@ struct web_service {
     COUNTER_DATA IISRequestsOther;
 };
 
+struct ws3svc_w3wp_data {
+    RRDSET *st_wescv_w3wp_active_threads;
+    RRDDIM *rd_wescv_w3wp_active_threads;
+
+    RRDSET *st_wescv_w3wp_requests_total;
+    RRDDIM *rd_wescv_w3wp_requests_total;
+
+    RRDSET *st_wescv_w3wp_requests_active;
+    RRDDIM *rd_wescv_w3wp_requests_active;
+
+    RRDSET *st_wescv_w3wp_file_cache_mem_usage;
+    RRDDIM *rd_wescv_w3wp_file_cache_mem_usage;
+
+    RRDSET *st_wescv_w3wp_files_cache_total;
+    RRDDIM *rd_wescv_w3wp_files_cache_total;
+
+    RRDSET *st_wescv_w3wp_files_flushed_total;
+    RRDDIM *rd_wescv_w3wp_files_flushed_total;
+
+    RRDSET *st_wescv_w3wp_uri_cache_flushed;
+    RRDDIM *rd_wescv_w3wp_uri_cache_flushed;
+
+    RRDSET *st_wescv_w3wp_total_uri_cached;
+    RRDDIM *rd_wescv_w3wp_total_uri_cached;
+
+    RRDSET *st_wescv_w3wp_total_metadata_cache;
+    RRDDIM *rd_wescv_w3wp_total_metadata_cache;
+
+    RRDSET *st_wescv_w3wp_total_metadata_flushed;
+    RRDDIM *rd_wescv_w3wp_total_metadata_flushed;
+
+    RRDSET *st_wescv_w3wp_output_cache_active_flushed_items;
+    RRDDIM *rd_wescv_w3wp_output_cache_active_flushed_items;
+
+    RRDSET *st_wescv_w3wp_output_cache_memory_usage;
+    RRDDIM *rd_wescv_w3wp_output_cache_memory_usage;
+
+    RRDSET *st_wescv_w3wp_output_cache_flushed_total;
+    RRDDIM *rd_wescv_w3wp_output_cache_flushed_total;
+
+    COUNTER_DATA WESCVW3WPActiveThreads;
+
+    COUNTER_DATA WESCVW3WPRequestTotal;
+    COUNTER_DATA WESCVW3WPRequestActive;
+
+    COUNTER_DATA WESCVW3WPFileCacheMemUsage;
+
+    COUNTER_DATA WESCVW3WPFilesCachedTotal;
+    COUNTER_DATA WESCVW3WPFilesFlushedTotal;
+
+    COUNTER_DATA WESCVW3WPURICachedFlushed;
+    COUNTER_DATA WESCVW3WPTotalURICached;
+
+    COUNTER_DATA WESCVW3WPTotalMetadataCached;
+    COUNTER_DATA WESCVW3WPTotalMetadataFlushed;
+
+    COUNTER_DATA WESCVW3WPOutputCacheActiveFlushedItens;
+    COUNTER_DATA WESCVW3WPOutputCacheMemoryUsage;
+    COUNTER_DATA WESCVW3WPOutputCacheFlushesTotal;
+};
+
 // AD information
 struct iis_app {
     RRDSET *st_app_current_application_pool_state;
@@ -208,8 +269,38 @@ void dict_app_pool_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *v
     initialize_app_pool_keys(p);
 }
 
+static inline void initialize_w3svc_w3wp_keys(struct ws3svc_w3wp_data *p)
+{
+    p->WESCVW3WPActiveThreads.key = "Active Threads Count";
+
+    p->WESCVW3WPRequestTotal.key = "Total HTTP Requests Served";
+    p->WESCVW3WPRequestActive.key = "Active Requests";
+
+    p->WESCVW3WPFileCacheMemUsage.key = "Current File Cache Memory Usage";
+
+    p->WESCVW3WPFilesCachedTotal.key = "Total Files Cached";
+    p->WESCVW3WPFilesFlushedTotal.key = "Total Flushed Files";
+
+    p->WESCVW3WPURICachedFlushed.key = "Total Flushed URIs";
+    p->WESCVW3WPTotalURICached.key = "Total URIs Cached";
+
+    p->WESCVW3WPTotalMetadataCached.key = "Total Metadata Cached";
+    p->WESCVW3WPTotalMetadataFlushed.key = "Total Flushed Metadata";
+
+    p->WESCVW3WPOutputCacheActiveFlushedItens.key = "Output Cache Current Flushed Items";
+    p->WESCVW3WPOutputCacheMemoryUsage.key = "Output Cache Current Memory Usage";
+    p->WESCVW3WPOutputCacheFlushesTotal.key = "Output Cache Total Flushes";
+}
+
+void dict_wesvc_w3wp_insert_cb(const DICTIONARY_ITEM *item __maybe_unused, void *value, void *data __maybe_unused)
+{
+    struct ws3svc_w3wp_data *p = value;
+    initialize_w3svc_w3wp_keys(p);
+}
+
 static DICTIONARY *web_services = NULL;
 static DICTIONARY *app_pools = NULL;
+static DICTIONARY *w3svc_w3wp_service = NULL;
 
 static void initialize(void)
 {
@@ -224,6 +315,11 @@ static void initialize(void)
         DICT_OPTION_DONT_OVERWRITE_VALUE | DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct iis_app));
 
     dictionary_register_insert_callback(app_pools, dict_app_pool_insert_cb, NULL);
+
+    w3svc_w3wp_service = dictionary_create_advanced(
+        DICT_OPTION_DONT_OVERWRITE_VALUE | DICT_OPTION_FIXED_SIZE, NULL, sizeof(struct ws3svc_w3wp_data));
+
+    dictionary_register_insert_callback(w3svc_w3wp_service, dict_wesvc_w3wp_insert_cb, NULL);
 }
 
 static inline void netdata_webservice_traffic(
@@ -1281,7 +1377,594 @@ static int iis_web_service(char *name, int update_every, typeof(bool(PERF_DATA_B
     return 0;
 }
 
-int do_PerflibWebService(int update_every, usec_t dt __maybe_unused)
+static inline void w3svc_w3wp_active_threads(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPActiveThreads)) {
+        if (!p->st_wescv_w3wp_active_threads) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_active_threads", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_active_threads = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_active_threads",
+                "Threads actively processing requests in the worker process",
+                "threads",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_ACTIVE_THREADS,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_active_threads =
+                rrddim_add(p->st_wescv_w3wp_active_threads, "active", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+            rrdlabels_add(p->st_wescv_w3wp_active_threads->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_active_threads,
+            p->rd_wescv_w3wp_active_threads,
+            (collected_number)p->WESCVW3WPActiveThreads.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_active_threads);
+    }
+}
+
+static inline void w3svc_w3wp_requests_total(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPRequestTotal)) {
+        if (!p->st_wescv_w3wp_requests_total) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_requests_total", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_requests_total = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_requests_total",
+                "HTTP requests served by the worker process.",
+                "requests/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_REQUESTS_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_requests_total =
+                rrddim_add(p->st_wescv_w3wp_requests_total, "requests", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_requests_total->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_requests_total,
+            p->rd_wescv_w3wp_requests_total,
+            (collected_number)p->WESCVW3WPRequestTotal.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_requests_total);
+    }
+}
+
+static inline void w3svc_w3wp_requests_active(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPRequestActive)) {
+        if (!p->st_wescv_w3wp_requests_active) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_requests_active", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_requests_active = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_requests_active",
+                "Current number of requests being processed by the worker process",
+                "requests",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_REQUESTS_ACTIVE,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_requests_active =
+                rrddim_add(p->st_wescv_w3wp_requests_active, "active", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+            rrdlabels_add(p->st_wescv_w3wp_requests_active->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_requests_active,
+            p->rd_wescv_w3wp_requests_active,
+            (collected_number)p->WESCVW3WPRequestActive.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_requests_active);
+    }
+}
+
+static inline void w3svc_w3wp_file_cache_mem_usage(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPFileCacheMemUsage)) {
+        if (!p->st_wescv_w3wp_file_cache_mem_usage) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_file_cache_mem_usage", windows_shared_buffer);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_file_cache_mem_usage = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_file_cache_mem_usage",
+                "Current memory usage by the worker process.",
+                "bytes",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_FILE_CACHE_MEM_USAGE,
+                update_every,
+                RRDSET_TYPE_AREA);
+
+            p->rd_wescv_w3wp_file_cache_mem_usage =
+                rrddim_add(p->st_wescv_w3wp_file_cache_mem_usage, "used", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+            rrdlabels_add(p->st_wescv_w3wp_file_cache_mem_usage->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_file_cache_mem_usage,
+            p->rd_wescv_w3wp_file_cache_mem_usage,
+            (collected_number)p->WESCVW3WPFileCacheMemUsage.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_file_cache_mem_usage);
+    }
+}
+
+static inline void w3svc_w3wp_files_cached_total(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPFilesCachedTotal)) {
+        if (!p->st_wescv_w3wp_files_cache_total) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_files_cache_total", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_files_cache_total = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_files_cache_total",
+                "Files whose contents were ever added to the cache",
+                "files/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_FILE_CACHE_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_files_cache_total =
+                rrddim_add(p->st_wescv_w3wp_files_cache_total, "cached_files", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_files_cache_total->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_files_cache_total,
+            p->rd_wescv_w3wp_files_cache_total,
+            (collected_number)p->WESCVW3WPFilesCachedTotal.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_files_cache_total);
+    }
+}
+
+static inline void w3svc_w3wp_files_flushed_total(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPFilesFlushedTotal)) {
+        if (!p->st_wescv_w3wp_files_flushed_total) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_files_flushed_total", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_files_flushed_total = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_files_flushed_total",
+                "File handles that have been removed from the cache",
+                "flushes/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_FILE_FLUSHED_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_files_flushed_total =
+                rrddim_add(p->st_wescv_w3wp_files_flushed_total, "file_handles", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_files_flushed_total->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_files_flushed_total,
+            p->rd_wescv_w3wp_files_flushed_total,
+            (collected_number)p->WESCVW3WPFilesFlushedTotal.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_files_flushed_total);
+    }
+}
+
+static inline void w3svc_w3wp_uri_cached_flushed(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPURICachedFlushed)) {
+        if (!p->st_wescv_w3wp_uri_cache_flushed) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_uri_cache_flushed", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_uri_cache_flushed = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_uri_cache_flushed",
+                "URI cache flushes",
+                "flushes/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_URI_FLUSHED_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_uri_cache_flushed =
+                rrddim_add(p->st_wescv_w3wp_uri_cache_flushed, "cached_uris", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_uri_cache_flushed->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_uri_cache_flushed,
+            p->rd_wescv_w3wp_uri_cache_flushed,
+            (collected_number)p->WESCVW3WPURICachedFlushed.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_uri_cache_flushed);
+    }
+}
+
+static inline void w3svc_w3wp_total_uri_cached(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPTotalURICached)) {
+        if (!p->st_wescv_w3wp_total_uri_cached) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_total_uri_cached", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_total_uri_cached = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_total_uri_cached",
+                "URI information blocks added to the cache",
+                "blocks/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_URI_CACHED_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_total_uri_cached =
+                rrddim_add(p->st_wescv_w3wp_total_uri_cached, "uri_cache_blocks", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_total_uri_cached->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_total_uri_cached,
+            p->rd_wescv_w3wp_total_uri_cached,
+            (collected_number)p->WESCVW3WPTotalURICached.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_total_uri_cached);
+    }
+}
+
+static inline void w3svc_w3wp_total_metadata_cached(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPTotalMetadataCached)) {
+        if (!p->st_wescv_w3wp_total_metadata_cache) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_total_metadata_cache", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_total_metadata_cache = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_total_metadata_cached",
+                "Metadata information blocks added to the user-mode cache",
+                "blocks/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_METADATA_CACHED,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_total_metadata_cache =
+                rrddim_add(p->st_wescv_w3wp_total_metadata_cache, "metadata_blocks", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_total_metadata_cache->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_total_metadata_cache,
+            p->rd_wescv_w3wp_total_metadata_cache,
+            (collected_number)p->WESCVW3WPTotalMetadataCached.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_total_metadata_cache);
+    }
+}
+
+static inline void w3svc_w3wp_total_metadata_flushed(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPTotalMetadataFlushed)) {
+        if (!p->st_wescv_w3wp_total_metadata_flushed) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_total_metadata_flushed", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_total_metadata_flushed = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_total_metadata_flushed",
+                "User-mode metadata cache flushed",
+                "flushes/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_METADATA_FLUSHED,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_total_metadata_flushed =
+                rrddim_add(p->st_wescv_w3wp_total_metadata_flushed, "metadata_blocks", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_total_metadata_flushed->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_total_metadata_flushed,
+            p->rd_wescv_w3wp_total_metadata_flushed,
+            (collected_number)p->WESCVW3WPTotalMetadataFlushed.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_total_metadata_flushed);
+    }
+}
+
+static inline void w3svc_w3wp_output_cache_active_flushed_items(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPOutputCacheActiveFlushedItens)) {
+        if (!p->st_wescv_w3wp_output_cache_active_flushed_items) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_output_cache_active_flushed_items", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_output_cache_active_flushed_items = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_output_cache_active_flushed_items",
+                "Items flushed but still in memory for active responses",
+                "items",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_OUTPUT_CACHE_ACTIVE_FLUSH,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_output_cache_active_flushed_items = rrddim_add(
+                p->st_wescv_w3wp_output_cache_active_flushed_items, "used", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+            rrdlabels_add(
+                p->st_wescv_w3wp_output_cache_active_flushed_items->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_output_cache_active_flushed_items,
+            p->rd_wescv_w3wp_output_cache_active_flushed_items,
+            (collected_number)p->WESCVW3WPOutputCacheActiveFlushedItens.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_output_cache_active_flushed_items);
+    }
+}
+
+static inline void w3svc_w3wp_output_cache_memory_usage(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPOutputCacheMemoryUsage)) {
+        if (!p->st_wescv_w3wp_output_cache_memory_usage) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_output_cache_memory_usage", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_output_cache_memory_usage = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_output_cache_memory_usage",
+                "Current number of bytes used by output cache",
+                "bytes",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_OUTPUT_CACHE_MEMORY_USAGE,
+                update_every,
+                RRDSET_TYPE_AREA);
+
+            p->rd_wescv_w3wp_output_cache_memory_usage =
+                rrddim_add(p->st_wescv_w3wp_output_cache_memory_usage, "used", NULL, 1, 1, RRD_ALGORITHM_ABSOLUTE);
+            rrdlabels_add(p->st_wescv_w3wp_output_cache_memory_usage->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_output_cache_memory_usage,
+            p->rd_wescv_w3wp_output_cache_memory_usage,
+            (collected_number)p->WESCVW3WPOutputCacheMemoryUsage.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_output_cache_memory_usage);
+    }
+}
+
+static inline void w3svc_w3wp_output_cache_flushed_total(
+    struct ws3svc_w3wp_data *p,
+    PERF_DATA_BLOCK *pDataBlock,
+    PERF_OBJECT_TYPE *pObjectType,
+    PERF_INSTANCE_DEFINITION *pi,
+    int update_every,
+    char *app_name)
+{
+    if (perflibGetInstanceCounter(pDataBlock, pObjectType, pi, &p->WESCVW3WPOutputCacheFlushesTotal)) {
+        if (!p->st_wescv_w3wp_output_cache_flushed_total) {
+            char id[RRD_ID_LENGTH_MAX + 1];
+            snprintfz(id, RRD_ID_LENGTH_MAX, "w3svc_w3wp_%s_output_cache_flushed_total", app_name);
+            netdata_fix_chart_name(id);
+            p->st_wescv_w3wp_output_cache_flushed_total = rrdset_create_localhost(
+                "iis",
+                id,
+                NULL,
+                "w3svc w3wp",
+                "iis.w3svc_w3wp_output_cache_flushed_total",
+                "Flushes of output cache",
+                "flushes/s",
+                PLUGIN_WINDOWS_NAME,
+                "PerflibWebService",
+                PRIO_W3SVC_W3WP_OUTPUT_CACHE_FLUSHED_TOTAL,
+                update_every,
+                RRDSET_TYPE_LINE);
+
+            p->rd_wescv_w3wp_output_cache_flushed_total = rrddim_add(
+                p->st_wescv_w3wp_output_cache_flushed_total, "output_cache_entries", NULL, 1, 1, RRD_ALGORITHM_INCREMENTAL);
+            rrdlabels_add(p->st_wescv_w3wp_output_cache_flushed_total->rrdlabels, "app", app_name, RRDLABEL_SRC_AUTO);
+        }
+
+        rrddim_set_by_pointer(
+            p->st_wescv_w3wp_output_cache_flushed_total,
+            p->rd_wescv_w3wp_output_cache_flushed_total,
+            (collected_number)p->WESCVW3WPOutputCacheFlushesTotal.current.Data);
+
+        rrdset_done(p->st_wescv_w3wp_output_cache_flushed_total);
+    }
+}
+
+static bool do_W3SCV_W3WP(PERF_DATA_BLOCK *pDataBlock, int update_every)
+{
+    PERF_OBJECT_TYPE *pObjectType = perflibFindObjectTypeByName(pDataBlock, "W3SVC_W3WP");
+    if (!pObjectType)
+        return false;
+
+    PERF_INSTANCE_DEFINITION *pi = NULL;
+    for (LONG i = 0; i < pObjectType->NumInstances; i++) {
+        pi = perflibForEachInstance(pDataBlock, pObjectType, pi);
+        if (!pi)
+            break;
+
+        if (!getInstanceName(pDataBlock, pObjectType, pi, windows_shared_buffer, sizeof(windows_shared_buffer)))
+            strncpyz(windows_shared_buffer, "[unknown]", sizeof(windows_shared_buffer) - 1);
+
+        // We are not ploting _Total here, because cloud will group the sites
+        if (strcasecmp(windows_shared_buffer, "_Total") == 0) {
+            continue;
+        }
+
+        struct ws3svc_w3wp_data *p = dictionary_set(w3svc_w3wp_service, windows_shared_buffer, NULL, sizeof(*p));
+        // Instance example: "11084_MSExchangeOABAppPool"
+        char *app = strchr(windows_shared_buffer, '_');
+        if (!app) {
+            continue;
+        }
+
+        *app++ = '\0';
+
+        w3svc_w3wp_active_threads(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_requests_total(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_requests_active(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_file_cache_mem_usage(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_files_cached_total(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_files_flushed_total(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_uri_cached_flushed(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_total_uri_cached(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_total_metadata_cached(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_total_metadata_flushed(p, pDataBlock, pObjectType, pi, update_every, app);
+
+        w3svc_w3wp_output_cache_active_flushed_items(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_output_cache_memory_usage(p, pDataBlock, pObjectType, pi, update_every, app);
+        w3svc_w3wp_output_cache_flushed_total(p, pDataBlock, pObjectType, pi, update_every, app);
+    }
+
+    return true;
+}
+
+int do_PerflibWebService(int update_every __maybe_unused, usec_t dt __maybe_unused)
 {
     static bool initialized = false;
 
@@ -1291,11 +1974,13 @@ int do_PerflibWebService(int update_every, usec_t dt __maybe_unused)
     }
 
     int ret = 0;
-#define TOTAL_NUMBER_OF_FAILURES (2)
+#define TOTAL_NUMBER_OF_FAILURES (3)
     if (iis_web_service("Web Service", update_every, do_web_services))
         ret++;
     if (iis_web_service("APP_POOL_WAS", update_every, do_app_pool))
         ret++;
+    if (iis_web_service("W3SVC_W3WP", update_every, do_W3SCV_W3WP))
+        ret++;
 
     return (ret == TOTAL_NUMBER_OF_FAILURES) ? -1 : 0;
 }
