@@ -1,10 +1,9 @@
 use crate::offset_array::{Cursor, InlinedCursor, List};
 use error::{JournalError, Result};
-use std::fs::File;
-use std::num::{NonZeroU64, NonZeroUsize};
-use window_manager::MemoryMap;
+use std::num::{NonZeroU32, NonZeroU64, NonZeroUsize};
 use zerocopy::{
-    ByteSlice, FromBytes, Immutable, IntoBytes, KnownLayout, Ref, SplitByteSlice, SplitByteSliceMut,
+    ByteSlice, ByteSliceMut, FromBytes, Immutable, IntoBytes, KnownLayout, Ref, SplitByteSlice,
+    SplitByteSliceMut,
 };
 
 pub trait HashableObject {
@@ -15,12 +14,145 @@ pub trait HashableObject {
     fn get_payload(&self) -> &[u8];
 
     /// Get the offset to the next object in the hash chain
-    fn next_hash_offset(&self) -> u64;
+    fn next_hash_offset(&self) -> Option<NonZeroU64>;
 
     /// Get the object type
     fn object_type() -> ObjectType;
 }
 
+pub trait HashableObjectMut: HashableObject {
+    /// Set the offset to the next object in the hash chain
+    fn set_next_hash_offset(&mut self, offset: NonZeroU64);
+
+    /// Set the payload of the object
+    fn set_payload(&mut self, data: &[u8]);
+}
+
+/// Trait for hash table operations
+pub trait HashTable {
+    /// The type of objects stored in this hash table
+    type Object: HashableObject;
+
+    /// Get the hash item for a given hash value
+    fn hash_item_ref(&self, hash: u64) -> &HashItem;
+
+    /// Get the length of the hash table (number of buckets)
+    fn len(&self) -> usize;
+
+    /// Make clippy happy
+    fn is_empty(&self) -> bool {
+        todo!()
+    }
+}
+
+/// Trait for mutable hash table operations
+pub trait HashTableMut: HashTable {
+    /// Get a mutable reference to the hash item for a given hash value
+    fn hash_item_mut(&mut self, hash: u64) -> &mut HashItem;
+}
+
+pub struct DataHashTable<B: ByteSlice> {
+    pub header: Ref<B, ObjectHeader>,
+    pub items: Ref<B, [HashItem]>,
+}
+
+pub struct FieldHashTable<B: ByteSlice> {
+    pub header: Ref<B, ObjectHeader>,
+    pub items: Ref<B, [HashItem]>,
+}
+
+// Implement HashTable for DataHashTable
+impl<B: ByteSlice> HashTable for DataHashTable<B> {
+    type Object = DataObject<B>;
+
+    fn hash_item_ref(&self, hash: u64) -> &HashItem {
+        let bucket_index = hash as usize % self.items.len();
+        &self.items[bucket_index]
+    }
+
+    fn len(&self) -> usize {
+        self.items.len()
+    }
+}
+
+// Implement HashTable for FieldHashTable
+impl<B: ByteSlice> HashTable for FieldHashTable<B> {
+    type Object = FieldObject<B>;
+
+    fn hash_item_ref(&self, hash: u64) -> &HashItem {
+        let bucket_index = hash as usize % self.items.len();
+        &self.items[bucket_index]
+    }
+
+    fn len(&self) -> usize {
+        self.items.len()
+    }
+}
+
+// Implement HashTableMut for DataHashTable
+impl<B: ByteSliceMut> HashTableMut for DataHashTable<B> {
+    fn hash_item_mut(&mut self, hash: u64) -> &mut HashItem {
+        let bucket_index = hash as usize % self.items.len();
+        &mut self.items[bucket_index]
+    }
+}
+
+// Implement HashTableMut for FieldHashTable
+impl<B: ByteSliceMut> HashTableMut for FieldHashTable<B> {
+    fn hash_item_mut(&mut self, hash: u64) -> &mut HashItem {
+        let bucket_index = hash as usize % self.items.len();
+        &mut self.items[bucket_index]
+    }
+}
+
+// Implement JournalObject for DataHashTable
+impl<B: SplitByteSlice> JournalObject<B> for DataHashTable<B> {
+    fn from_data(data: B, _is_compact: bool) -> Option<Self> {
+        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).ok()?;
+
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
+        let items = zerocopy::Ref::from_bytes(items_data).ok()?;
+
+        Some(DataHashTable { header, items })
+    }
+}
+
+// Implement JournalObjectMut for DataHashTable
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for DataHashTable<B> {
+    fn from_data_mut(data: B, _is_compact: bool) -> Option<Self> {
+        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).ok()?;
+
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
+        let items = zerocopy::Ref::from_bytes(items_data).ok()?;
+
+        Some(DataHashTable { header, items })
+    }
+}
+
+// Implement JournalObject for FieldHashTable
+impl<B: SplitByteSlice> JournalObject<B> for FieldHashTable<B> {
+    fn from_data(data: B, _is_compact: bool) -> Option<Self> {
+        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).ok()?;
+
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
+        let items = zerocopy::Ref::from_bytes(items_data).ok()?;
+
+        Some(FieldHashTable { header, items })
+    }
+}
+
+// Implement JournalObjectMut for FieldHashTable
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for FieldHashTable<B> {
+    fn from_data_mut(data: B, _is_compact: bool) -> Option<Self> {
+        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).ok()?;
+
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
+        let items = zerocopy::Ref::from_bytes(items_data).ok()?;
+
+        Some(FieldHashTable { header, items })
+    }
+}
+
 impl<B: ByteSlice> HashableObject for FieldObject<B> {
     fn hash(&self) -> u64 {
         self.header.hash
@@ -30,7 +162,7 @@ impl<B: ByteSlice> HashableObject for FieldObject<B> {
         &self.payload
     }
 
-    fn next_hash_offset(&self) -> u64 {
+    fn next_hash_offset(&self) -> Option<NonZeroU64> {
         self.header.next_hash_offset
     }
 
@@ -39,7 +171,17 @@ impl<B: ByteSlice> HashableObject for FieldObject<B> {
     }
 }
 
-impl<B: ByteSlice + SplitByteSlice + std::fmt::Debug> HashableObject for DataObject<B> {
+impl HashableObjectMut for FieldObject<&mut [u8]> {
+    fn set_next_hash_offset(&mut self, next_hash_offset: NonZeroU64) {
+        self.header.next_hash_offset = Some(next_hash_offset);
+    }
+
+    fn set_payload(&mut self, data: &[u8]) {
+        self.payload.copy_from_slice(data);
+    }
+}
+
+impl<B: ByteSlice> HashableObject for DataObject<B> {
     fn hash(&self) -> u64 {
         self.header.hash
     }
@@ -48,7 +190,7 @@ impl<B: ByteSlice + SplitByteSlice + std::fmt::Debug> HashableObject for DataObj
         self.payload_bytes()
     }
 
-    fn next_hash_offset(&self) -> u64 {
+    fn next_hash_offset(&self) -> Option<NonZeroU64> {
         self.header.next_hash_offset
     }
 
@@ -57,15 +199,32 @@ impl<B: ByteSlice + SplitByteSlice + std::fmt::Debug> HashableObject for DataObj
     }
 }
 
+impl HashableObjectMut for DataObject<&mut [u8]> {
+    fn set_next_hash_offset(&mut self, next_hash_offset: NonZeroU64) {
+        self.header.next_hash_offset = Some(next_hash_offset);
+    }
+
+    fn set_payload(&mut self, data: &[u8]) {
+        match &mut self.payload {
+            DataPayloadType::Regular(payload) => {
+                payload.copy_from_slice(data);
+            }
+            DataPayloadType::Compact { payload, .. } => {
+                payload.copy_from_slice(data);
+            }
+        };
+    }
+}
+
 /// Trait to standardize creation of journal objects from byte slices
 pub trait JournalObject<B: SplitByteSlice>: Sized {
     /// Create a new journal object from a byte slice
     fn from_data(data: B, is_compact: bool) -> Option<Self>;
 }
 
-pub trait JournalObjectMut<B: SplitByteSliceMut>: Sized {
+pub trait JournalObjectMut<B: SplitByteSliceMut>: JournalObject<B> {
     /// Create a new journal object from a byte slice
-    fn from_data_mut(data: B, is_compact: bool) -> Self;
+    fn from_data_mut(data: B, is_compact: bool) -> Option<Self>;
 }
 
 pub enum HeaderIncompatibleFlags {
@@ -104,30 +263,30 @@ impl TryFrom<u8> for JournalState {
 #[derive(Default, Debug, Clone, Copy, FromBytes, IntoBytes, Immutable, KnownLayout)]
 #[repr(C)]
 pub struct JournalHeader {
-    pub signature: [u8; 8],           // "LPKSHHRH"
-    pub compatible_flags: u32,        // Compatible extension flags
-    pub incompatible_flags: u32,      // Incompatible extension flags
-    pub state: u8,                    // File state (offline=0, online=1, archived=2)
-    pub reserved: [u8; 7],            // Reserved space
-    pub file_id: [u8; 16],            // Unique ID for this file
-    pub machine_id: [u8; 16],         // Machine ID this belongs to
-    pub tail_entry_boot_id: [u8; 16], // Boot ID of the last entry
-    pub seqnum_id: [u8; 16],          // Sequence number ID
-    pub header_size: u64,             // Size of the header
-    pub arena_size: u64,              // Size of the data arena
-    pub data_hash_table_offset: u64,  // Offset of the data hash table
-    pub data_hash_table_size: u64,    // Size of the data hash table
-    pub field_hash_table_offset: u64, // Offset of the field hash table
-    pub field_hash_table_size: u64,   // Size of the field hash table
-    pub tail_object_offset: u64,      // Offset of the last object
-    pub n_objects: u64,               // Number of objects
-    pub n_entries: u64,               // Number of entries
-    pub tail_entry_seqnum: u64,       // Sequence number of the last entry
-    pub head_entry_seqnum: u64,       // Sequence number of the first entry
-    pub entry_array_offset: u64,      // Offset of the entry array
-    pub head_entry_realtime: u64,     // Realtime timestamp of the first entry
-    pub tail_entry_realtime: u64,     // Realtime timestamp of the last entry
-    pub tail_entry_monotonic: u64,    // Monotonic timestamp of the last entry
+    pub signature: [u8; 8],                          // "LPKSHHRH"
+    pub compatible_flags: u32,                       // Compatible extension flags
+    pub incompatible_flags: u32,                     // Incompatible extension flags
+    pub state: u8,                                   // File state (offline=0, online=1, archived=2)
+    pub reserved: [u8; 7],                           // Reserved space
+    pub file_id: [u8; 16],                           // Unique ID for this file
+    pub machine_id: [u8; 16],                        // Machine ID this belongs to
+    pub tail_entry_boot_id: [u8; 16],                // Boot ID of the last entry
+    pub seqnum_id: [u8; 16],                         // Sequence number ID
+    pub header_size: u64,                            // Size of the header
+    pub arena_size: u64,                             // Size of the data arena
+    pub data_hash_table_offset: Option<NonZeroU64>,  // Offset of the data hash table
+    pub data_hash_table_size: Option<NonZeroU64>,    // Size of the data hash table
+    pub field_hash_table_offset: Option<NonZeroU64>, // Offset of the field hash table
+    pub field_hash_table_size: Option<NonZeroU64>,   // Size of the field hash table
+    pub tail_object_offset: Option<NonZeroU64>,      // Offset of the last object
+    pub n_objects: u64,                              // Number of objects
+    pub n_entries: u64,                              // Number of entries
+    pub tail_entry_seqnum: u64,                      // Sequence number of the last entry
+    pub head_entry_seqnum: u64,                      // Sequence number of the first entry
+    pub entry_array_offset: Option<NonZeroU64>,      // Offset of the entry array
+    pub head_entry_realtime: u64,                    // Realtime timestamp of the first entry
+    pub tail_entry_realtime: u64,                    // Realtime timestamp of the last entry
+    pub tail_entry_monotonic: u64,                   // Monotonic timestamp of the last entry
 }
 
 /*
@@ -157,38 +316,6 @@ impl JournalHeader {
     pub fn has_compatible_flag(&self, flag: HeaderCompatibleFlags) -> bool {
         (self.compatible_flags & flag as u32) != 0
     }
-
-    fn map_hash_table<M: MemoryMap>(
-        &self,
-        file: &File,
-        offset: u64,
-        size: u64,
-    ) -> Result<Option<M>> {
-        if offset == 0 || size == 0 {
-            return Ok(None);
-        }
-
-        let object_header_size = std::mem::size_of::<ObjectHeader>() as u64;
-        if offset <= object_header_size || size < object_header_size {
-            return Err(JournalError::InvalidObjectLocation);
-        }
-
-        let position = offset - object_header_size;
-        let map_size = object_header_size + size;
-        M::create(file, position, map_size).map(Some)
-    }
-
-    pub fn map_data_hash_table<M: MemoryMap>(&self, file: &File) -> Result<Option<M>> {
-        self.map_hash_table(file, self.data_hash_table_offset, self.data_hash_table_size)
-    }
-
-    pub fn map_field_hash_table<M: MemoryMap>(&self, file: &File) -> Result<Option<M>> {
-        self.map_hash_table(
-            file,
-            self.field_hash_table_offset,
-            self.field_hash_table_size,
-        )
-    }
 }
 
 pub enum ObjectFlags {
@@ -264,49 +391,22 @@ impl ObjectHeader {
 pub struct FieldObjectHeader {
     pub object_header: ObjectHeader,
     pub hash: u64,
-    pub next_hash_offset: u64,
-    pub head_data_offset: u64,
+    pub next_hash_offset: Option<NonZeroU64>,
+    pub head_data_offset: Option<NonZeroU64>,
 }
 
 #[derive(Debug, Copy, Clone, FromBytes, IntoBytes, KnownLayout, Immutable)]
 #[repr(C)]
 pub struct OffsetArrayObjectHeader {
     pub object_header: ObjectHeader,
-    pub next_offset_array: u64,
+    pub next_offset_array: Option<NonZeroU64>,
 }
 
 #[derive(Debug, Copy, Clone, FromBytes, IntoBytes, KnownLayout, Immutable)]
 #[repr(C)]
 pub struct HashItem {
-    pub head_hash_offset: u64,
-    pub tail_hash_offset: u64,
-}
-
-pub struct HashTableObject<B: ByteSlice> {
-    pub header: Ref<B, ObjectHeader>,
-    pub items: Ref<B, [HashItem]>,
-}
-
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for HashTableObject<B> {
-    fn from_data(data: B, _is_compact: bool) -> Option<Self> {
-        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).ok()?;
-
-        let header = zerocopy::Ref::from_bytes(header_data).unwrap();
-        let items = zerocopy::Ref::from_bytes(items_data).unwrap();
-
-        Some(HashTableObject { header, items })
-    }
-}
-
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for HashTableObject<B> {
-    fn from_data_mut(data: B, _is_compact: bool) -> Self {
-        let (header_data, items_data) = data.split_at(std::mem::size_of::<ObjectHeader>()).unwrap();
-
-        let header = zerocopy::Ref::from_bytes(header_data).unwrap();
-        let items = zerocopy::Ref::from_bytes(items_data).unwrap();
-
-        HashTableObject { header, items }
-    }
+    pub head_hash_offset: Option<NonZeroU64>,
+    pub tail_hash_offset: Option<NonZeroU64>,
 }
 
 #[derive(Debug)]
@@ -315,31 +415,39 @@ pub struct FieldObject<B: ByteSlice> {
     pub payload: B,
 }
 
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for FieldObject<B> {
+impl<B: SplitByteSlice> JournalObject<B> for FieldObject<B> {
     fn from_data(data: B, _is_compact: bool) -> Option<Self> {
         let (header, payload) = zerocopy::Ref::from_prefix(data).ok()?;
         Some(FieldObject { header, payload })
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for FieldObject<B> {
-    fn from_data_mut(data: B, _is_compact: bool) -> Self {
-        let (header, payload) = zerocopy::Ref::from_prefix(data).unwrap();
-
-        FieldObject { header, payload }
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for FieldObject<B> {
+    fn from_data_mut(data: B, _is_compact: bool) -> Option<Self> {
+        let (header, payload) = zerocopy::Ref::from_prefix(data).ok()?;
+        Some(FieldObject { header, payload })
     }
 }
 
 pub enum OffsetsType<B: ByteSlice> {
-    Regular(Ref<B, [u64]>),
-    Compact(Ref<B, [u32]>),
+    Regular(Ref<B, [Option<NonZeroU64>]>),
+    Compact(Ref<B, [Option<NonZeroU32>]>),
 }
 
 impl<B: ByteSlice> OffsetsType<B> {
-    pub fn get(&self, index: usize) -> u64 {
+    pub fn get(&self, index: usize) -> Option<NonZeroU64> {
         match self {
             OffsetsType::Regular(offsets) => offsets[index],
-            OffsetsType::Compact(offsets) => offsets[index] as u64,
+            OffsetsType::Compact(offsets) => offsets[index].map(NonZeroU64::from),
+        }
+    }
+}
+
+impl<B: ByteSliceMut> OffsetsType<B> {
+    pub fn set(&mut self, index: usize, value: NonZeroU64) {
+        match self {
+            OffsetsType::Regular(offsets) => offsets[index] = Some(value),
+            OffsetsType::Compact(offsets) => offsets[index] = NonZeroU32::new(value.get() as u32),
         }
     }
 }
@@ -374,35 +482,22 @@ impl<B: ByteSlice> OffsetArrayObject<B> {
         self.len(remaining_items) == 0
     }
 
-    pub fn get(&self, index: usize, remaining_items: usize) -> Result<u64> {
+    pub fn get(&self, index: usize, remaining_items: usize) -> Result<Option<NonZeroU64>> {
         if self.is_empty(remaining_items) {
             return Err(JournalError::EmptyOffsetArrayNode);
         }
 
-        let offset = match &self.items {
-            OffsetsType::Regular(items) => items[index],
-            OffsetsType::Compact(items) => items[index] as u64,
-        };
-
-        if offset == 0 {
-            Err(JournalError::InvalidOffsetArrayOffset)
-        } else {
-            Ok(offset)
-        }
+        Ok(self.items.get(index))
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> OffsetArrayObject<B> {
+impl<B: ByteSliceMut> OffsetArrayObject<B> {
     pub fn set(&mut self, index: usize, offset: NonZeroU64) -> Result<()> {
         if index >= self.capacity() {
             return Err(JournalError::OutOfBoundsIndex);
         }
 
-        match &mut self.items {
-            OffsetsType::Regular(items) => items[index] = offset.get(),
-            OffsetsType::Compact(items) => items[index] = offset.get() as u32,
-        };
-
+        self.items.set(index, offset);
         Ok(())
     }
 }
@@ -415,7 +510,7 @@ impl<B: ByteSlice> std::fmt::Debug for OffsetArrayObject<B> {
     }
 }
 
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for OffsetArrayObject<B> {
+impl<B: SplitByteSlice> JournalObject<B> for OffsetArrayObject<B> {
     fn from_data(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, items_data) = data
             .split_at(std::mem::size_of::<OffsetArrayObjectHeader>())
@@ -438,26 +533,26 @@ impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for OffsetArrayObject
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for OffsetArrayObject<B> {
-    fn from_data_mut(data: B, is_compact: bool) -> Self {
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for OffsetArrayObject<B> {
+    fn from_data_mut(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, items_data) = data
             .split_at(std::mem::size_of::<OffsetArrayObjectHeader>())
-            .unwrap();
+            .ok()?;
 
-        let header = zerocopy::Ref::from_bytes(header_data).unwrap();
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
 
         let items_type = if is_compact {
-            let compact_items = zerocopy::Ref::from_bytes(items_data).unwrap();
+            let compact_items = zerocopy::Ref::from_bytes(items_data).ok()?;
             OffsetsType::Compact(compact_items)
         } else {
-            let regular_items = zerocopy::Ref::from_bytes(items_data).unwrap();
+            let regular_items = zerocopy::Ref::from_bytes(items_data).ok()?;
             OffsetsType::Regular(regular_items)
         };
 
-        OffsetArrayObject {
+        Some(OffsetArrayObject {
             header,
             items: items_type,
-        }
+        })
     }
 }
 
@@ -492,6 +587,22 @@ pub enum EntryItemsType<B: ByteSlice> {
     Compact(Ref<B, [CompactEntryItem]>),
 }
 
+impl<B: ByteSliceMut> EntryItemsType<B> {
+    pub fn set(&mut self, index: usize, object_offset: NonZeroU64, hash: Option<u64>) {
+        match self {
+            EntryItemsType::Regular(entry_items) => {
+                entry_items[index].object_offset = object_offset.get();
+                entry_items[index].hash = hash.unwrap();
+            }
+            EntryItemsType::Compact(entry_items) => {
+                debug_assert!(hash.is_none());
+                assert!(object_offset.get() < u32::MAX as u64);
+                entry_items[index].object_offset = object_offset.get() as u32;
+            }
+        }
+    }
+}
+
 impl<B: ByteSlice> EntryItemsType<B> {
     pub fn get(&self, index: usize) -> u64 {
         match self {
@@ -538,7 +649,7 @@ impl<B: ByteSlice> std::fmt::Debug for EntryObject<B> {
     }
 }
 
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for EntryObject<B> {
+impl<B: SplitByteSlice> JournalObject<B> for EntryObject<B> {
     fn from_data(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, items_data) = data
             .split_at(std::mem::size_of::<EntryObjectHeader>())
@@ -561,26 +672,26 @@ impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for EntryObject<B> {
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for EntryObject<B> {
-    fn from_data_mut(data: B, is_compact: bool) -> Self {
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for EntryObject<B> {
+    fn from_data_mut(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, items_data) = data
             .split_at(std::mem::size_of::<EntryObjectHeader>())
-            .unwrap();
+            .ok()?;
 
-        let header = zerocopy::Ref::from_bytes(header_data).unwrap();
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
 
         let items_type = if is_compact {
-            let compact_items = zerocopy::Ref::from_bytes(items_data).unwrap();
+            let compact_items = zerocopy::Ref::from_bytes(items_data).ok()?;
             EntryItemsType::Compact(compact_items)
         } else {
-            let regular_items = zerocopy::Ref::from_bytes(items_data).unwrap();
+            let regular_items = zerocopy::Ref::from_bytes(items_data).ok()?;
             EntryItemsType::Regular(regular_items)
         };
 
-        EntryObject {
+        Some(EntryObject {
             header,
             items: items_type,
-        }
+        })
     }
 }
 
@@ -589,11 +700,11 @@ impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for EntryObject
 pub struct DataObjectHeader {
     pub object_header: ObjectHeader,
     pub hash: u64,
-    pub next_hash_offset: u64,
-    pub next_field_offset: u64,
-    pub entry_offset: u64,
-    pub entry_array_offset: u64,
-    pub n_entries: u64,
+    pub next_hash_offset: Option<NonZeroU64>,
+    pub next_field_offset: Option<NonZeroU64>,
+    pub entry_offset: Option<NonZeroU64>,
+    pub entry_array_offset: Option<NonZeroU64>,
+    pub n_entries: Option<NonZeroU64>,
 }
 
 impl DataObjectHeader {
@@ -614,21 +725,19 @@ impl DataObjectHeader {
     }
 
     pub fn inlined_cursor(&self) -> Option<InlinedCursor> {
-        if self.n_entries == 0 {
-            return None;
-        }
-
-        let inlined_offset = NonZeroU64::new(self.entry_offset)?;
-        let cursor = self.entry_array_offset_list().map(Cursor::at_head);
+        let inlined_offset = self.entry_offset?;
+        let cursor = match self.n_entries?.get() {
+            1 => None,
+            n => {
+                let total_items = unsafe { NonZeroUsize::new_unchecked(n as usize - 1) };
+                Some(Cursor::at_head(List::new(
+                    self.entry_array_offset?,
+                    total_items,
+                )))
+            }
+        };
         Some(InlinedCursor::new(inlined_offset, cursor))
     }
-
-    pub fn entry_array_offset_list(&self) -> Option<List> {
-        let total_items = NonZeroUsize::new(self.n_entries.saturating_sub(1) as usize)?;
-        let head_offset = NonZeroU64::new(self.entry_array_offset)?;
-
-        Some(List::new(head_offset, total_items))
-    }
 }
 
 #[derive(Debug, Copy, Clone, FromBytes, IntoBytes, KnownLayout, Immutable, PartialEq, Eq)]
@@ -679,7 +788,7 @@ impl<B: ByteSlice> std::fmt::Debug for DataObject<B> {
     }
 }
 
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for DataObject<B> {
+impl<B: SplitByteSlice> JournalObject<B> for DataObject<B> {
     fn from_data(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, remaining_data) = data
             .split_at(std::mem::size_of::<DataObjectHeader>())
@@ -706,20 +815,20 @@ impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for DataObject<B> {
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for DataObject<B> {
-    fn from_data_mut(data: B, is_compact: bool) -> Self {
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for DataObject<B> {
+    fn from_data_mut(data: B, is_compact: bool) -> Option<Self> {
         let (header_data, remaining_data) = data
             .split_at(std::mem::size_of::<DataObjectHeader>())
-            .unwrap();
+            .ok()?;
 
-        let header = zerocopy::Ref::from_bytes(header_data).unwrap();
+        let header = zerocopy::Ref::from_bytes(header_data).ok()?;
 
         let payload = if is_compact {
             let (fields_data, payload_data) = remaining_data
                 .split_at(std::mem::size_of::<CompactDataFields>())
-                .unwrap();
+                .ok()?;
 
-            let compact_fields = zerocopy::Ref::from_bytes(fields_data).unwrap();
+            let compact_fields = zerocopy::Ref::from_bytes(fields_data).ok()?;
 
             DataPayloadType::Compact {
                 compact_fields,
@@ -729,11 +838,11 @@ impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for DataObject<
             DataPayloadType::Regular(remaining_data)
         };
 
-        DataObject { header, payload }
+        Some(DataObject { header, payload })
     }
 }
 
-impl<B: ByteSlice + SplitByteSlice + std::fmt::Debug> DataObject<B> {
+impl<B: ByteSlice> DataObject<B> {
     pub fn payload_bytes(&self) -> &[u8] {
         match &self.payload {
             DataPayloadType::Regular(payload) => payload,
@@ -806,21 +915,21 @@ impl<B: ByteSlice> std::fmt::Debug for TagObject<B> {
     }
 }
 
-impl<B: SplitByteSlice + std::fmt::Debug> JournalObject<B> for TagObject<B> {
+impl<B: SplitByteSlice> JournalObject<B> for TagObject<B> {
     fn from_data(data: B, _is_compact: bool) -> Option<Self> {
         let header = zerocopy::Ref::from_bytes(data).ok()?;
         Some(TagObject { header })
     }
 }
 
-impl<B: SplitByteSliceMut + std::fmt::Debug> JournalObjectMut<B> for TagObject<B> {
-    fn from_data_mut(data: B, _is_compact: bool) -> Self {
-        let header = zerocopy::Ref::from_bytes(data).unwrap();
-        TagObject { header }
+impl<B: SplitByteSliceMut> JournalObjectMut<B> for TagObject<B> {
+    fn from_data_mut(data: B, _is_compact: bool) -> Option<Self> {
+        let header = zerocopy::Ref::from_bytes(data).ok()?;
+        Some(TagObject { header })
     }
 }
 
-impl<B: ByteSlice + SplitByteSlice + std::fmt::Debug> TagObject<B> {
+impl<B: ByteSlice> TagObject<B> {
     // Helper function to format tag as hex string
     pub fn tag_as_hex(&self) -> String {
         self.header
