@@ -1,4 +1,4 @@
-use crate::journal_file::JournalFile;
+use crate::file::JournalFile;
 use error::{JournalError, Result};
 use std::num::{NonZeroU64, NonZeroUsize};
 use window_manager::MemoryMap;
@@ -25,21 +25,21 @@ impl Node {
         offset: NonZeroU64,
         remaining_items: NonZeroUsize,
     ) -> Result<Self> {
-        let array = journal_file.offset_array_ref(offset.get())?;
+        let array = journal_file.offset_array_ref(offset)?;
         let capacity =
             NonZeroUsize::new(array.capacity()).ok_or(JournalError::EmptyOffsetArrayNode)?;
 
         Ok(Self {
             offset,
-            next_offset: NonZeroU64::new(array.header.next_offset_array),
+            next_offset: array.header.next_offset_array,
             capacity,
             remaining_items,
         })
     }
 
     /// Get the offset of this array in the file
-    pub fn offset(&self) -> u64 {
-        self.offset.get()
+    pub fn offset(&self) -> NonZeroU64 {
+        self.offset
     }
 
     /// Get the maximum number of items this array can hold
@@ -74,12 +74,16 @@ impl Node {
     }
 
     /// Get an item at the specified index
-    pub fn get<M: MemoryMap>(&self, journal_file: &JournalFile<M>, index: usize) -> Result<u64> {
+    pub fn get<M: MemoryMap>(
+        &self,
+        journal_file: &JournalFile<M>,
+        index: usize,
+    ) -> Result<Option<NonZeroU64>> {
         if index >= self.len().get() {
             return Err(JournalError::InvalidOffsetArrayIndex);
         }
 
-        let array = journal_file.offset_array_ref(self.offset.get())?;
+        let array = journal_file.offset_array_ref(self.offset)?;
         array.get(index, self.remaining_items.get())
     }
 
@@ -94,7 +98,7 @@ impl Node {
     ) -> Result<usize>
     where
         M: MemoryMap,
-        F: Fn(u64) -> Result<bool>,
+        F: Fn(NonZeroU64) -> Result<bool>,
     {
         let mut left = left;
         let mut right = right;
@@ -104,7 +108,9 @@ impl Node {
 
         while left != right {
             let mid = left.midpoint(right);
-            let offset = self.get(journal_file, mid)?;
+            let Some(offset) = self.get(journal_file, mid)? else {
+                return Err(JournalError::InvalidOffset);
+            };
 
             if predicate(offset)? {
                 left = mid + 1;
@@ -127,7 +133,7 @@ impl Node {
     ) -> Result<Option<usize>>
     where
         M: MemoryMap,
-        F: Fn(u64) -> Result<bool>,
+        F: Fn(NonZeroU64) -> Result<bool>,
     {
         let index = self.partition_point(journal_file, left, right, predicate)?;
 
@@ -229,7 +235,7 @@ impl List {
     ) -> Result<Option<Cursor>>
     where
         M: MemoryMap,
-        F: Fn(u64) -> Result<bool>,
+        F: Fn(NonZeroU64) -> Result<bool>,
     {
         let mut last_cursor: Option<Cursor> = None;
 
@@ -361,7 +367,7 @@ impl Cursor {
         Node::new(journal_file, self.array_offset, self.remaining_items)
     }
 
-    pub fn value<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<u64> {
+    pub fn value<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<Option<NonZeroU64>> {
         self.node(journal_file)?.get(journal_file, self.array_index)
     }
 
@@ -538,10 +544,10 @@ impl InlinedCursor {
         unreachable!();
     }
 
-    pub fn value<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<u64> {
+    pub fn value<M: MemoryMap>(&self, journal_file: &JournalFile<M>) -> Result<Option<NonZeroU64>> {
         // Case 1: We're at the inlined entry
         if self.at_inlined_offset {
-            return Ok(self.inlined_offset.get());
+            return Ok(Some(self.inlined_offset));
         }
 
         // Case 2: We're in the entry array
@@ -555,9 +561,12 @@ impl InlinedCursor {
     pub fn next_until<M: MemoryMap>(
         &mut self,
         journal_file: &JournalFile<M>,
-        offset: u64,
-    ) -> Result<Option<u64>> {
-        let current_offset = self.value(journal_file)?;
+        offset: NonZeroU64,
+    ) -> Result<Option<NonZeroU64>> {
+        let Some(current_offset) = self.value(journal_file)? else {
+            return Ok(None);
+        };
+
         if current_offset >= offset {
             return Ok(Some(current_offset));
         }
@@ -565,7 +574,10 @@ impl InlinedCursor {
         while let Some(ic) = self.next(journal_file)? {
             *self = ic;
 
-            let current_offset = self.value(journal_file)?;
+            let Some(current_offset) = self.value(journal_file)? else {
+                break;
+            };
+
             if current_offset >= offset {
                 return Ok(Some(current_offset));
             }
@@ -577,9 +589,12 @@ impl InlinedCursor {
     pub fn previous_until<M: MemoryMap>(
         &mut self,
         journal_file: &JournalFile<M>,
-        offset: u64,
-    ) -> Result<Option<u64>> {
-        let current_offset = self.value(journal_file)?;
+        offset: NonZeroU64,
+    ) -> Result<Option<NonZeroU64>> {
+        let Some(current_offset) = self.value(journal_file)? else {
+            return Ok(None);
+        };
+
         if current_offset <= offset {
             return Ok(Some(current_offset));
         }
@@ -587,7 +602,10 @@ impl InlinedCursor {
         while let Some(ic) = self.previous(journal_file)? {
             *self = ic;
 
-            let current_offset = ic.value(journal_file)?;
+            let Some(current_offset) = ic.value(journal_file)? else {
+                break;
+            };
+
             if current_offset <= offset {
                 return Ok(Some(current_offset));
             }
@@ -604,7 +622,7 @@ impl InlinedCursor {
     ) -> Result<Option<Self>>
     where
         M: MemoryMap,
-        F: Fn(u64) -> Result<bool>,
+        F: Fn(NonZeroU64) -> Result<bool>,
     {
         // Variables to track our best match
         let mut best_match: Option<Self> = None;
@@ -612,12 +630,12 @@ impl InlinedCursor {
         // Handle the inlined entry based on direction
         match direction {
             Direction::Forward => {
-                if !predicate(self.inlined_offset.get())? {
+                if !predicate(self.inlined_offset)? {
                     return Ok(Some(self.head()));
                 }
             }
             Direction::Backward => {
-                if predicate(self.inlined_offset.get())? {
+                if predicate(self.inlined_offset)? {
                     // If predicate is true for inlined entry and we're going backward,
                     // this is potentially our best match
                     best_match = Some(self.head());
