@@ -7,10 +7,14 @@ void print_build_info(void);
 
 void print_build_info_json(void);
 
+void print_build_info_cmake_cache(void);
+
 char *get_value_from_key(char *buffer, char *key);
 
 void get_install_type(struct rrdhost_system_info *system_info);
 
 void build_info_to_json_object(BUFFER *b);
 
+void get_install_type_internal(char **install_type, char **prebuilt_arch, char **prebuilt_dist);
+
 #endif // NETDATA_BUILDINFO_H
