@@ -322,69 +322,3 @@ func TestConfig_Apply(t *testing.T) {
 		})
 	}
 }
-
-func Test_urlResolveHostname(t *testing.T) {
-	tests := map[string]struct {
-		input       string
-		wantChanged bool
-	}{
-		"hostname with suffix": {
-			wantChanged: true,
-			input:       "http://hostname.local:80/metrics",
-		},
-		"hostname without suffix": {
-			wantChanged: true,
-			input:       "http://hostname:80/metrics",
-		},
-		"no hostname": {
-			wantChanged: false,
-			input:       "http://127.0.0.1:80/metrics",
-		},
-	}
-
-	for name, test := range tests {
-		t.Run(name, func(t *testing.T) {
-
-			if test.wantChanged {
-				assert.NotEqual(t, test.input, urlResolveHostname(test.input))
-			} else {
-				assert.Equal(t, test.input, urlResolveHostname(test.input))
-			}
-		})
-	}
-}
-
-func Test_jobNameResolveHostname(t *testing.T) {
-	tests := map[string]struct {
-		input       string
-		wantChanged bool
-	}{
-		"hostname with dot suffix": {
-			wantChanged: true,
-			input:       "hostname.local",
-		},
-		"hostname with underscore suffix": {
-			wantChanged: true,
-			input:       "hostname_local",
-		},
-		"hostname without suffix": {
-			wantChanged: true,
-			input:       "hostname",
-		},
-		"no hostname": {
-			wantChanged: false,
-			input:       "name",
-		},
-	}
-
-	for name, test := range tests {
-		t.Run(name, func(t *testing.T) {
-
-			if test.wantChanged {
-				assert.NotEqual(t, test.input, jobNameResolveHostname(test.input))
-			} else {
-				assert.Equal(t, test.input, jobNameResolveHostname(test.input))
-			}
-		})
-	}
-}
