@@ -5,21 +5,29 @@ package pipeline
 import (
 	"errors"
 	"fmt"
+	"strings"
 
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/confgroup"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/discovery/sd/discoverer/dockersd"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/discovery/sd/discoverer/k8ssd"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/discovery/sd/discoverer/netlistensd"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/discovery/sd/discoverer/snmpsd"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/discovery/sd/model"
 )
 
 type Config struct {
 	Source         string             `yaml:"-"`
 	ConfigDefaults confgroup.Registry `yaml:"-"`
 
-	Disabled bool                 `yaml:"disabled"`
-	Name     string               `yaml:"name"`
-	Discover []DiscoveryConfig    `yaml:"discover"`
+	Disabled bool   `yaml:"disabled"`
+	Name     string `yaml:"name"`
+
+	Discover []DiscoveryConfig `yaml:"discover"`
+
+	// New single-step format:
+	Services []ServiceRuleConfig `yaml:"services"`
+
+	// Legacy two-step:
 	Classify []ClassifyRuleConfig `yaml:"classify"`
 	Compose  []ComposeRuleConfig  `yaml:"compose"`
 }
@@ -32,6 +40,12 @@ type DiscoveryConfig struct {
 	SNMP         snmpsd.Config      `yaml:"snmp"`
 }
 
+type ServiceRuleConfig struct {
+	ID             string `yaml:"id"`              // mandatory (for logging/diagnostics)
+	Match          string `yaml:"match"`           // mandatory
+	ConfigTemplate string `yaml:"config_template"` // optional (drop if empty)
+}
+
 type ClassifyRuleConfig struct {
 	Name     string `yaml:"name"`
 	Selector string `yaml:"selector"` // mandatory
@@ -58,11 +72,20 @@ func validateConfig(cfg Config) error {
 	if err := validateDiscoveryConfig(cfg.Discover); err != nil {
 		return fmt.Errorf("discover config: %v", err)
 	}
-	if err := validateClassifyConfig(cfg.Classify); err != nil {
-		return fmt.Errorf("classify rules: %v", err)
-	}
-	if err := validateComposeConfig(cfg.Compose); err != nil {
-		return fmt.Errorf("compose rules: %v", err)
+
+	switch {
+	case len(cfg.Services) > 0:
+		if err := validateServicesConfig(cfg.Services); err != nil {
+			return fmt.Errorf("services rules: %v", err)
+		}
+	default:
+		// Legacy path
+		if err := validateClassifyConfig(cfg.Classify); err != nil {
+			return fmt.Errorf("classify rules: %v", err)
+		}
+		if err := validateComposeConfig(cfg.Compose); err != nil {
+			return fmt.Errorf("compose rules: %v", err)
+		}
 	}
 	return nil
 }
@@ -81,6 +104,23 @@ func validateDiscoveryConfig(config []DiscoveryConfig) error {
 	return nil
 }
 
+func validateServicesConfig(rules []ServiceRuleConfig) error {
+	if len(rules) == 0 {
+		return errors.New("empty config, need at least 1 service rule")
+	}
+	for i, r := range rules {
+		i++
+		if r.ID == "" {
+			return fmt.Errorf("'service[%d]->id' not set", i)
+		}
+		if r.Match == "" {
+			return fmt.Errorf("'service[%s][%d]->match' not set", r.ID, i)
+		}
+		// config_template is optional
+	}
+	return nil
+}
+
 func validateClassifyConfig(rules []ClassifyRuleConfig) error {
 	if len(rules) == 0 {
 		return errors.New("empty config, need least 1 rule")
@@ -136,3 +176,51 @@ func validateComposeConfig(rules []ComposeRuleConfig) error {
 	}
 	return nil
 }
+
+func ConvertOldToServices(cls []ClassifyRuleConfig, cmp []ComposeRuleConfig) ([]ServiceRuleConfig, error) {
+	var out []ServiceRuleConfig
+
+	// Build quick lookups for tag -> list of match exprs that add this tag.
+	tagToExprs := map[string][]string{}
+	for _, r := range cls {
+		for _, m := range r.Match {
+			// split tags line into tokens:
+			tags, _ := model.ParseTags(m.Tags) // reuse existing parser if accessible
+			for tag := range tags {
+				if strings.HasPrefix(tag, "-") { // ignore deletions
+					continue
+				}
+				tagToExprs[tag] = append(tagToExprs[tag], m.Expr)
+			}
+		}
+		// also include rule-level tags
+		rtags, _ := model.ParseTags(r.Tags)
+		for tag := range rtags {
+			if strings.HasPrefix(tag, "-") {
+				continue
+			}
+			// no expr here; this is too generic to build a service rule from.
+		}
+	}
+
+	// For each compose rule config entry, create services for its selector tags.
+	for _, r := range cmp {
+		for _, c := range r.Config {
+			sel := strings.TrimSpace(c.Selector)
+			exprs := tagToExprs[sel]
+			for i, expr := range exprs {
+				id := sel
+				if i > 0 {
+					id = fmt.Sprintf("%s_%d", sel, i+1)
+				}
+				out = append(out, ServiceRuleConfig{
+					ID:             id,
+					Match:          expr,
+					ConfigTemplate: c.Template,
+				})
+			}
+		}
+	}
+
+	return out, nil
+}
