@@ -3,7 +3,6 @@
 package jobmgr
 
 import (
-	"github.com/netdata/netdata/go/plugins/pkg/netdataapi"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/functions"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/vnodes"
 )
@@ -13,13 +12,6 @@ type Vnodes interface {
 }
 
 type FunctionRegistry interface {
-	Register(name string, reg func(functions.Function))
-	Unregister(name string)
-}
-
-type dyncfgAPI interface {
-	CONFIGCREATE(opts netdataapi.ConfigOpts)
-	CONFIGDELETE(id string)
-	CONFIGSTATUS(id, status string)
-	FUNCRESULT(result netdataapi.FunctionResult)
+	RegisterPrefix(name, prefix string, fn func(functions.Function))
+	UnregisterPrefix(name string, prefix string)
 }
