@@ -8,6 +8,7 @@ import (
 	"io"
 	"log/slog"
 	"os"
+	"path/filepath"
 	"slices"
 	"strings"
 	"sync"
@@ -18,6 +19,7 @@ import (
 	"github.com/netdata/netdata/go/plugins/pkg/safewriter"
 	"github.com/netdata/netdata/go/plugins/pkg/ticker"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/confgroup"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/dyncfg"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/functions"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/vnodes"
@@ -44,11 +46,11 @@ func New() *Manager {
 		runningJobs:       newRunningJobsCache(),
 		retryingTasks:     newRetryingTasksCache(),
 
-		started:  make(chan struct{}),
-		api:      netdataapi.New(safewriter.Stdout),
-		addCh:    make(chan confgroup.Config),
-		rmCh:     make(chan confgroup.Config),
-		dyncfgCh: make(chan functions.Function),
+		started:   make(chan struct{}),
+		addCh:     make(chan confgroup.Config),
+		rmCh:      make(chan confgroup.Config),
+		dyncfgCh:  make(chan functions.Function),
+		dyncfgApi: dyncfg.NewResponder(netdataapi.New(safewriter.Stdout)),
 	}
 
 	return mgr
@@ -66,6 +68,11 @@ type Manager struct {
 	FnReg          FunctionRegistry
 	Vnodes         map[string]*vnodes.VirtualNode
 
+	// Dump mode
+	DumpMode     bool
+	DumpAnalyzer interface{} // Will be *agent.DumpAnalyzer but avoid circular dependency
+	DumpDataDir  string
+
 	fileStatus *fileStatus
 
 	discoveredConfigs *discoveredConfigs
@@ -74,14 +81,16 @@ type Manager struct {
 	retryingTasks     *retryingTasks
 	runningJobs       *runningJobs
 
-	ctx      context.Context
-	started  chan struct{}
-	api      dyncfgAPI
+	ctx     context.Context
+	started chan struct{}
+	//api      dyncfgAPI
 	addCh    chan confgroup.Config
 	rmCh     chan confgroup.Config
 	dyncfgCh chan functions.Function
 
 	waitCfgOnOff string // block processing of discovered configs until "enable"/"disable" is received from Netdata
+
+	dyncfgApi *dyncfg.Responder
 }
 
 func (m *Manager) Run(ctx context.Context, in chan []*confgroup.Group) {
@@ -89,12 +98,13 @@ func (m *Manager) Run(ctx context.Context, in chan []*confgroup.Group) {
 	defer func() { m.cleanup(); m.Info("instance is stopped") }()
 	m.ctx = ctx
 
-	m.FnReg.Register("config", m.dyncfgConfig)
+	m.FnReg.RegisterPrefix("config", m.dyncfgCollectorPrefixValue(), m.dyncfgConfig)
+	m.FnReg.RegisterPrefix("config", m.dyncfgVnodePrefixValue(), m.dyncfgConfig)
 
 	m.dyncfgVnodeModuleCreate()
 
 	for _, cfg := range m.Vnodes {
-		m.dyncfgVnodeJobCreate(cfg, dyncfgRunning)
+		m.dyncfgVnodeJobCreate(cfg, dyncfg.StatusRunning)
 	}
 
 	for name := range m.Modules {
@@ -151,7 +161,7 @@ func (m *Manager) run() {
 			case <-m.ctx.Done():
 				return
 			case fn := <-m.dyncfgCh:
-				m.dyncfgCollectorSeqExec(fn)
+				m.dyncfgSeqExec(fn)
 			}
 		} else {
 			select {
@@ -162,14 +172,7 @@ func (m *Manager) run() {
 			case cfg := <-m.rmCh:
 				m.removeConfig(cfg)
 			case fn := <-m.dyncfgCh:
-				switch id := fn.Args[0]; true {
-				case strings.HasPrefix(id, dyncfgCollectorIDPrefix):
-					m.dyncfgCollectorSeqExec(fn)
-				case strings.HasPrefix(id, dyncfgVnodeID):
-					m.dyncfgVnodeSeqExec(fn)
-				default:
-					m.dyncfgRespf(fn, 503, "unknown function '%s' (%s).", fn.Name, id)
-				}
+				m.dyncfgSeqExec(fn)
 			}
 		}
 	}
@@ -190,19 +193,19 @@ func (m *Manager) addConfig(cfg confgroup.Config) {
 
 	ecfg, ok := m.exposedConfigs.lookup(cfg)
 	if !ok {
-		scfg.status = dyncfgAccepted
+		scfg.status = dyncfg.StatusAccepted
 		ecfg = scfg
 		m.exposedConfigs.add(ecfg)
 	} else {
 		sp, ep := scfg.cfg.SourceTypePriority(), ecfg.cfg.SourceTypePriority()
-		if ep > sp || (ep == sp && ecfg.status == dyncfgRunning) {
+		if ep > sp || (ep == sp && ecfg.status == dyncfg.StatusRunning) {
 			return
 		}
-		if ecfg.status == dyncfgRunning {
+		if ecfg.status == dyncfg.StatusRunning {
 			m.stopRunningJob(ecfg.cfg.FullName())
 			m.fileStatus.remove(ecfg.cfg)
 		}
-		scfg.status = dyncfgAccepted
+		scfg.status = dyncfg.StatusAccepted
 		m.exposedConfigs.add(scfg) // replace existing exposed
 		ecfg = scfg
 	}
@@ -210,7 +213,7 @@ func (m *Manager) addConfig(cfg confgroup.Config) {
 	m.dyncfgCollectorJobCreate(ecfg.cfg, ecfg.status)
 
 	if isTerminal || m.PluginName == "nodyncfg" { // FIXME: quick fix of TestAgent_Run (agent_test.go)
-		m.dyncfgConfigEnable(functions.Function{Args: []string{dyncfgJobID(ecfg.cfg), "enable"}})
+		m.dyncfgConfigEnable(functions.Function{Args: []string{m.dyncfgJobID(ecfg.cfg), "enable"}})
 	} else {
 		m.waitCfgOnOff = ecfg.cfg.FullName()
 	}
@@ -234,7 +237,7 @@ func (m *Manager) removeConfig(cfg confgroup.Config) {
 	m.stopRunningJob(cfg.FullName())
 	m.fileStatus.remove(cfg)
 
-	if !isStock(cfg) || ecfg.status == dyncfgRunning {
+	if !isStock(cfg) || ecfg.status == dyncfg.StatusRunning {
 		m.dyncfgJobRemove(cfg)
 	}
 }
@@ -278,7 +281,8 @@ func (m *Manager) stopRunningJob(name string) {
 }
 
 func (m *Manager) cleanup() {
-	m.FnReg.Unregister("config")
+	m.FnReg.UnregisterPrefix("config", m.dyncfgCollectorPrefixValue())
+	m.FnReg.UnregisterPrefix("config", m.dyncfgVnodePrefixValue())
 
 	m.runningJobs.lock()
 	defer m.runningJobs.unlock()
@@ -312,6 +316,20 @@ func (m *Manager) createCollectorJob(cfg confgroup.Config) (*module.Job, error)
 		return nil, err
 	}
 
+	var jobDumpDir string
+	if m.DumpDataDir != "" {
+		jobDumpDir = filepath.Join(m.DumpDataDir, sanitizeName(cfg.Module()), sanitizeName(cfg.Name()))
+		if err := os.MkdirAll(jobDumpDir, 0o755); err != nil {
+			return nil, fmt.Errorf("creating dump directory: %w", err)
+		}
+		if analyzer, ok := m.DumpAnalyzer.(interface{ RegisterJob(string, string, string) }); ok {
+			analyzer.RegisterJob(cfg.Name(), cfg.Module(), jobDumpDir)
+		}
+		if dumpAware, ok := mod.(interface{ EnableDump(string) }); ok {
+			dumpAware.EnableDump(jobDumpDir)
+		}
+	}
+
 	jobCfg := module.JobConfig{
 		PluginName:      m.PluginName,
 		Name:            cfg.Name(),
@@ -324,7 +342,10 @@ func (m *Manager) createCollectorJob(cfg confgroup.Config) (*module.Job, error)
 		IsStock:         cfg.SourceType() == "stock",
 		Module:          mod,
 		Out:             m.Out,
+		DumpMode:        m.DumpMode,
+		DumpAnalyzer:    m.DumpAnalyzer,
 	}
+
 	if vnode != nil {
 		jobCfg.Vnode = *vnode.Copy()
 	}
@@ -334,6 +355,11 @@ func (m *Manager) createCollectorJob(cfg confgroup.Config) (*module.Job, error)
 	return job, nil
 }
 
+func sanitizeName(name string) string {
+	replacer := strings.NewReplacer("/", "_", "\\", "_", " ", "_", ":", "_", "*", "_", "?", "_", "\"", "_", "<", "_", ">", "_", "|", "_")
+	return replacer.Replace(name)
+}
+
 func runRetryTask(ctx context.Context, out chan<- confgroup.Config, cfg confgroup.Config) {
 	t := time.NewTimer(time.Second * time.Duration(cfg.AutoDetectionRetry()))
 	defer t.Stop()
