@@ -6,7 +6,7 @@ import (
 	"errors"
 	"strconv"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 )
 
 const querySystemAsyncMetrics = `
