@@ -3,7 +3,7 @@
 package freeradius
 
 import (
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/stm"
+	"github.com/netdata/netdata/go/plugins/pkg/stm"
 )
 
 func (c *Collector) collect() (map[string]int64, error) {
