@@ -6,10 +6,10 @@ import (
 	"math"
 	"strings"
 
+	"github.com/netdata/netdata/go/plugins/pkg/prometheus"
+	"github.com/netdata/netdata/go/plugins/pkg/stm"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
 	mtx "github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/metrix"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/prometheus"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/stm"
 )
 
 func (c *Collector) collect() (map[string]int64, error) {
