@@ -101,7 +101,10 @@ var baseCharts = module.Charts{
 	chartInnoDBIO.Copy(),
 	chartInnoDBIOOperations.Copy(),
 	chartInnoDBPendingIOOperations.Copy(),
+	chartInnoDBLogActivity.Copy(),
+	chartInnoDBLogOccupancy.Copy(),
 	chartInnoDBLogOperations.Copy(),
+	chartInnoDBCheckpointAge.Copy(),
 	chartInnoDBCurrentRowLocks.Copy(),
 	chartInnoDBRowsOperations.Copy(),
 	chartInnoDBBufferPoolPages.Copy(),
@@ -351,6 +354,19 @@ var (
 			{ID: "innodb_data_pending_fsyncs", Name: "fsyncs"},
 		},
 	}
+	chartInnoDBLogActivity = module.Chart{
+		ID:       "innodb_redo_log_activity",
+		Title:    "InnoDB Redo Log Activity",
+		Units:    "B/s",
+		Fam:      "innodb",
+		Ctx:      "mysql.innodb_redo_log_activity",
+		Type:     module.Line,
+		Priority: prioInnoDBLog,
+		Dims: module.Dims{
+			{ID: "innodb_log_sequence_number", Name: "redo_written", Algo: module.Incremental},
+			{ID: "innodb_last_checkpoint_at", Name: "checkpointed", Algo: module.Incremental},
+		},
+	}
 	chartInnoDBLogOperations = module.Chart{
 		ID:       "innodb_log",
 		Title:    "InnoDB Log Operations",
@@ -364,6 +380,29 @@ var (
 			{ID: "innodb_log_writes", Name: "writes", Algo: module.Incremental, Mul: -1},
 		},
 	}
+	chartInnoDBLogOccupancy = module.Chart{
+		ID:       "innodb_redo_log_occupancy",
+		Title:    "InnoDB Redo Log Occupancy",
+		Units:    "percentage",
+		Fam:      "innodb",
+		Ctx:      "mysql.innodb_redo_log_occupancy",
+		Type:     module.Area,
+		Priority: prioInnoDBLog,
+		Dims: module.Dims{
+			{ID: "innodb_log_occupancy", Name: "occupancy", Algo: module.Absolute, Div: 1000},
+		},
+	}
+	chartInnoDBCheckpointAge = module.Chart{
+		ID:       "innodb_redo_log_checkpoint_age",
+		Title:    "InnoDB Redo Log Checkpoint Age",
+		Units:    "B",
+		Fam:      "innodb",
+		Ctx:      "mysql.innodb_redo_log_checkpoint_age",
+		Priority: prioInnoDBLog,
+		Dims: module.Dims{
+			{ID: "innodb_checkpoint_age", Name: "age", Algo: module.Absolute},
+		},
+	}
 	chartInnoDBCurrentRowLocks = module.Chart{
 		ID:       "innodb_cur_row_lock",
 		Title:    "InnoDB Current Row Locks",
