@@ -15,8 +15,8 @@ import (
 	"github.com/blang/semver/v4"
 	"github.com/go-sql-driver/mysql"
 
+	"github.com/netdata/netdata/go/plugins/pkg/confopt"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/confopt"
 )
 
 //go:embed "config_schema.json"
@@ -52,6 +52,11 @@ func New() *Collector {
 		collectedUsers:                 make(map[string]bool),
 
 		recheckGlobalVarsEvery: time.Minute * 10,
+
+		// innodb_log_files_in_group is available in mysql and <mariadb-10.6,
+		// otherwise it defaults to 1.
+		// see https://mariadb.com/kb/en/innodb-system-variables/#innodb_log_files_in_group
+		varInnoDBLogFilesInGroup: 1,
 	}
 }
 
@@ -93,6 +98,8 @@ type Collector struct {
 
 	recheckGlobalVarsTime    time.Time
 	recheckGlobalVarsEvery   time.Duration
+	varInnoDBLogFileSize     int64
+	varInnoDBLogFilesInGroup int64
 	varMaxConns              int64
 	varTableOpenCache        int64
 	varDisabledStorageEngine string
