@@ -7,7 +7,7 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 )
 
 func (c *Collector) initClient() (client, error) {
