@@ -3,12 +3,10 @@
 package postfix
 
 import (
-	"context"
-	"fmt"
-	"os/exec"
 	"time"
 
 	"github.com/netdata/netdata/go/plugins/logger"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/ndexec"
 )
 
 type postqueueBinary interface {
@@ -30,16 +28,5 @@ type postqueueExec struct {
 }
 
 func (p *postqueueExec) list() ([]byte, error) {
-	ctx, cancel := context.WithTimeout(context.Background(), p.timeout)
-	defer cancel()
-
-	cmd := exec.CommandContext(ctx, p.binPath, "-p")
-	p.Debugf("executing '%s'", cmd)
-
-	bs, err := cmd.Output()
-	if err != nil {
-		return nil, fmt.Errorf("error on '%s': %v", cmd, err)
-	}
-
-	return bs, nil
+	return ndexec.RunUnprivileged(p.Logger, p.timeout, p.binPath, "-p")
 }
