@@ -6,8 +6,8 @@ import (
 	"errors"
 	"net/http"
 
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
 )
 
 func (c *Collector) validateConfig() error {
