@@ -9,7 +9,7 @@ import (
 	"slices"
 	"strings"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 )
 
 func (c *Collector) collect() (map[string]int64, error) {
