@@ -5,8 +5,8 @@ package rabbitmq
 import (
 	"fmt"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/stm"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/pkg/stm"
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 )
 
 func (c *Collector) collectOverview(mx map[string]int64) error {
