@@ -9,12 +9,12 @@ import (
 	"testing"
 	"time"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/confopt"
-
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/tidwall/gjson"
+
+	"github.com/netdata/netdata/go/plugins/pkg/confopt"
+	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/module"
 )
 
 var (
@@ -70,8 +70,8 @@ func TestCollector_Init(t *testing.T) {
 				return cfg
 			}(),
 		},
-		"fails if 'ndsudo' not found": {
-			wantFail: true,
+		"success with default config": {
+			wantFail: false,
 			config:   New().Config,
 		},
 	}
@@ -79,6 +79,7 @@ func TestCollector_Init(t *testing.T) {
 	for name, test := range tests {
 		t.Run(name, func(t *testing.T) {
 			collr := New()
+			collr.Config = test.config
 
 			if test.wantFail {
 				assert.Error(t, collr.Init(context.Background()))
