@@ -3,6 +3,8 @@
 package snmp
 
 import (
+	"context"
+	"errors"
 	"fmt"
 	"log/slog"
 	"maps"
@@ -10,9 +12,11 @@ import (
 	"slices"
 	"strconv"
 	"strings"
+	"syscall"
 
 	"github.com/google/uuid"
 	"github.com/gosnmp/gosnmp"
+	"golang.org/x/sync/errgroup"
 
 	"github.com/netdata/netdata/go/plugins/logger"
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/agent/vnodes"
@@ -21,60 +25,110 @@ import (
 	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/snmputils"
 )
 
-const oidSysUptime = "1.3.6.1.2.1.1.3.0"
-
 func (c *Collector) collect() (map[string]int64, error) {
-	if c.snmpClient == nil {
-		snmpClient, err := c.initAndConnectSNMPClient()
-		if err != nil {
-			return nil, err
-		}
-		c.snmpClient = snmpClient
-		if c.ddSnmpColl != nil {
-			c.ddSnmpColl.SetSNMPClient(snmpClient)
-		}
+	if err := c.ensureInitialized(); err != nil {
+		return nil, err
 	}
 
-	if c.sysInfo == nil {
-		si, err := snmputils.GetSysInfo(c.snmpClient)
-		if err != nil {
-			return nil, err
-		}
-
-		if c.enableProfiles {
-			c.snmpProfiles = c.setupProfiles(si)
-		}
-
-		if c.ddSnmpColl == nil {
-			c.ddSnmpColl = ddsnmpcollector.New(c.snmpClient, c.snmpProfiles, c.Logger, si.SysObjectID)
-		}
-
-		if c.CreateVnode {
-			deviceMeta, err := c.ddSnmpColl.CollectDeviceMetadata()
-			if err != nil {
-				return nil, err
-			}
-			c.vnode = c.setupVnode(si, deviceMeta)
-		}
-
-		c.sysInfo = si
-	}
-
-	mx := make(map[string]int64)
-
-	if err := c.collectProfiles(mx); err != nil {
-		c.Infof("failed to collect profiles: %v", err)
-	}
-
-	if !c.DisableLegacyCollection && len(c.customOids) > 0 {
-		if err := c.collectOIDs(mx); err != nil {
-			return nil, err
-		}
+	mx, err := c.collectMetrics()
+	if err != nil {
+		return nil, err
 	}
 
 	return mx, nil
 }
 
+func (c *Collector) collectMetrics() (map[string]int64, error) {
+	var (
+		snmpMx map[string]int64
+		pingMx map[string]int64
+	)
+
+	ctx := context.Background()
+
+	g, _ := errgroup.WithContext(ctx)
+
+	g.Go(func() error {
+		m := make(map[string]int64)
+		if err := c.collectSNMP(m); err != nil {
+			return err
+		}
+		snmpMx = m
+		return nil
+	})
+
+	if c.Ping.Enabled && c.prober != nil {
+		g.Go(func() error {
+			m := make(map[string]int64)
+			if err := c.collectPing(m); err != nil {
+				c.Errorf("ping: %v", err)
+				if isPingUnrecoverableError(err) {
+					c.prober = nil
+				}
+				return nil
+			}
+			pingMx = m
+			return nil
+		})
+	}
+
+	if err := g.Wait(); err != nil {
+		return nil, err
+	}
+
+	mx := make(map[string]int64, len(snmpMx)+len(pingMx))
+
+	maps.Copy(mx, snmpMx)
+	maps.Copy(mx, pingMx)
+
+	return mx, nil
+}
+
+func (c *Collector) ensureInitialized() error {
+	if c.snmpClient == nil {
+		return errors.New("snmp client not initialized")
+	}
+
+	if c.sysInfo != nil {
+		return nil
+	}
+
+	si, err := snmputils.GetSysInfo(c.snmpClient)
+	if err != nil {
+		return err
+	}
+
+	if c.snmpProfiles == nil {
+		c.snmpProfiles = c.setupProfiles(si)
+	}
+
+	if c.ddSnmpColl == nil && len(c.snmpProfiles) > 0 {
+		c.ddSnmpColl = c.newDdSnmpColl(ddsnmpcollector.Config{
+			SnmpClient:      c.snmpClient,
+			Profiles:        c.snmpProfiles,
+			Log:             c.Logger,
+			SysObjectID:     si.SysObjectID,
+			DisableBulkWalk: c.disableBulkWalk,
+		})
+	}
+
+	if c.CreateVnode {
+		deviceMeta, err := c.ddSnmpColl.CollectDeviceMetadata()
+		if err != nil {
+			return err
+		}
+		c.vnode = c.setupVnode(si, deviceMeta)
+	}
+
+	c.sysInfo = si
+
+	if c.Ping.Enabled {
+		c.addPingCharts()
+	}
+
+	return nil
+}
+
 func (c *Collector) setupVnode(si *snmputils.SysInfo, deviceMeta map[string]ddsnmp.MetaTag) *vnodes.VirtualNode {
 	if c.Vnode.GUID == "" {
 		c.Vnode.GUID = uuid.NewSHA1(uuid.NameSpaceDNS, []byte(c.Hostname)).String()
@@ -161,6 +215,10 @@ func (c *Collector) initAndConnectSNMPClient() (gosnmp.Handler, error) {
 		return nil, fmt.Errorf("connect: %w", err)
 	}
 
+	if snmpClient.Version() == gosnmp.Version1 {
+		return snmpClient, nil
+	}
+
 	if c.adjMaxRepetitions != 0 {
 		snmpClient.SetMaxRepetitions(c.adjMaxRepetitions)
 	} else {
@@ -169,15 +227,25 @@ func (c *Collector) initAndConnectSNMPClient() (gosnmp.Handler, error) {
 			return nil, fmt.Errorf("re-adjust max repetitions SNMP client: %w", err)
 		}
 		if !ok {
-			c.Warningf("SNMP bulk walk disabled: table metrics collection unavailable (device may not support GETBULK or max-repetitions adjustment failed)")
+			c.Warningf("SNMP bulk walk disabled (device may not support GETBULK or max-repetitions adjustment failed)")
+			c.disableBulkWalk = true
 		}
 		c.adjMaxRepetitions = snmpClient.MaxRepetitions()
-		c.snmpBulkWalkOk = ok
 	}
 
 	return snmpClient, nil
 }
+
 func (c *Collector) adjustMaxRepetitions(snmpClient gosnmp.Handler) (bool, error) {
+	ok, err := c.detectBulkWalkSupport(snmpClient)
+	if err != nil {
+		c.Warningf("bulk support probe error: %v", err)
+		return false, nil
+	}
+	if !ok {
+		return false, nil
+	}
+
 	orig := c.Config.Options.MaxRepetitions
 	maxReps := c.Config.Options.MaxRepetitions
 	attempts := 0
@@ -186,13 +254,13 @@ func (c *Collector) adjustMaxRepetitions(snmpClient gosnmp.Handler) (bool, error
 	for maxReps > 0 && attempts < maxAttempts {
 		attempts++
 
-		v, err := walkAll(snmpClient, snmputils.RootOidMibSystem)
+		v, err := snmpClient.BulkWalkAll(snmputils.RootOidMibSystem)
 		if err != nil {
 			return false, err
 		}
 
 		if len(v) > 0 {
-			//c.Config.Options.MaxRepetitions = maxReps
+			//c.Config.OptionsConfig.MaxRepetitions = maxReps
 			if orig != maxReps {
 				c.Infof("adjusted max_repetitions: %d → %d (took %d attempts)", orig, maxReps, attempts)
 			}
@@ -223,30 +291,24 @@ func (c *Collector) adjustMaxRepetitions(snmpClient gosnmp.Handler) (bool, error
 	return false, nil
 }
 
-func walkAll(snmpClient gosnmp.Handler, rootOid string) ([]gosnmp.SnmpPDU, error) {
+func isPingUnrecoverableError(err error) bool {
+	var errno syscall.Errno
+	return errors.As(err, &errno) && (errors.Is(errno, syscall.EPERM) || errors.Is(errno, syscall.EACCES))
+}
+
+func (c *Collector) detectBulkWalkSupport(snmpClient gosnmp.Handler) (bool, error) {
 	if snmpClient.Version() == gosnmp.Version1 {
-		return snmpClient.WalkAll(rootOid)
+		return false, nil
 	}
-	return snmpClient.BulkWalkAll(rootOid)
-}
 
-func pduToInt(pdu gosnmp.SnmpPDU) (int64, error) {
-	switch pdu.Type {
-	case gosnmp.Counter32, gosnmp.Counter64, gosnmp.Integer, gosnmp.Gauge32, gosnmp.TimeTicks:
-		return gosnmp.ToBigInt(pdu.Value).Int64(), nil
-	default:
-		return 0, fmt.Errorf("unsupported type: '%v'", pdu.Type)
+	// Use a very small max-reps for the probe to be gentle
+	orig := snmpClient.MaxRepetitions()
+	defer snmpClient.SetMaxRepetitions(orig)
+	snmpClient.SetMaxRepetitions(5)
+
+	oids, err := snmpClient.BulkWalkAll(snmputils.RootOidMibSystem)
+	if err != nil {
+		return false, err
 	}
+	return len(oids) > 0, nil
 }
-
-//func physAddressToString(pdu gosnmp.SnmpPDU) (string, error) {
-//	address, ok := pdu.Value.([]uint8)
-//	if !ok {
-//		return "", errors.New("physAddress is not a []uint8")
-//	}
-//	parts := make([]string, 0, 6)
-//	for _, v := range address {
-//		parts = append(parts, fmt.Sprintf("%02X", v))
-//	}
-//	return strings.Join(parts, ":"), nil
-//}
