@@ -274,9 +274,9 @@ func TestScalarCollector_Collect(t *testing.T) {
 								OID:  "1.3.6.1.2.1.1.3.0",
 								Name: "sysUpTime",
 							},
-							StaticTags: []string{
-								"source:system",
-								"type:uptime",
+							StaticTags: []ddprofiledefinition.StaticMetricTagConfig{
+								{Tag: "source", Value: "system"},
+								{Tag: "type", Value: "uptime"},
 							},
 						},
 					},
