@@ -5,8 +5,8 @@ package vernemq
 import (
 	"errors"
 
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/prometheus"
-	"github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/web"
+	"github.com/netdata/netdata/go/plugins/pkg/prometheus"
+	"github.com/netdata/netdata/go/plugins/pkg/web"
 )
 
 func (c *Collector) validateConfig() error {
