@@ -2,7 +2,9 @@
 
 package metrix
 
-import "github.com/netdata/netdata/go/plugins/plugin/go.d/pkg/stm"
+import (
+	"github.com/netdata/netdata/go/plugins/pkg/stm"
+)
 
 // Observer is an interface that wraps the Observe method, which is used by
 // Histogram and Summary to add observations.
