@@ -3,7 +3,6 @@
 #include "stream.h"
 #include "stream-thread.h"
 #include "stream-receiver-internals.h"
-#include "web/server/h2o/http_server.h"
 
 #ifdef NETDATA_LOG_STREAM_RECEIVER
 void stream_receiver_log_payload(struct receiver_state *rpt, const char *payload, STREAM_TRAFFIC_TYPE type __maybe_unused, bool inbound) {
@@ -124,17 +123,6 @@ static ssize_t write_stream(struct receiver_state *r, char* buffer, size_t size)
         return -2;
     }
 
-#ifdef ENABLE_H2O
-    if (is_h2o_rrdpush(r)) {
-        if(nd_thread_signaled_to_cancel()) {
-            errno_clear();
-            return -3;
-        }
-
-        return (ssize_t)h2o_stream_write(r->h2o_ctx, buffer, size);
-    }
-#endif
-
     ssize_t bytes_written = nd_sock_send_nowait(&r->sock, buffer, size);
     return bytes_written;
 }
@@ -147,17 +135,6 @@ static ssize_t read_stream(struct receiver_state *r, char* buffer, size_t size)
         return -2;
     }
 
-#ifdef ENABLE_H2O
-    if (is_h2o_rrdpush(r)) {
-        if(nd_thread_signaled_to_cancel()) {
-            errno_clear();
-            return -3;
-        }
-
-        return (ssize_t)h2o_stream_read(r->h2o_ctx, buffer, size);
-    }
-#endif
-
     ssize_t bytes_read = nd_sock_revc_nowait(&r->sock, buffer, size);
     return bytes_read;
 }
@@ -496,10 +473,6 @@ void stream_receiver_move_to_running_unsafe(struct stream_thread *sth, struct re
         __atomic_store_n(&rpt->thread.parser, parser, __ATOMIC_RELAXED);
     }
 
-#ifdef ENABLE_H2O
-    parser->h2o_ctx = rpt->h2o_ctx;
-#endif
-
     if(stream_receive.replication.enabled)
         pulse_host_status(rpt->host, PULSE_HOST_STATUS_RCV_REPLICATION_WAIT, 0);
     else
@@ -1100,6 +1073,7 @@ static void stream_receiver_replication_reset(RRDHOST *host) {
 
     __atomic_store_n(&host->stream.rcv.status.replication.counter_in, 0, __ATOMIC_RELAXED);
     __atomic_store_n(&host->stream.rcv.status.replication.counter_out, 0, __ATOMIC_RELAXED);
+    __atomic_store_n(&host->stream.rcv.status.replication.backfill_pending, 0, __ATOMIC_RELAXED);
 }
 
 bool rrdhost_set_receiver(RRDHOST *host, struct receiver_state *rpt) {
