@@ -1641,7 +1641,7 @@ static void replication_worker_cleanup(void *pptr) {
     worker_unregister();
 }
 
-static void *replication_worker_thread(void *ptr __maybe_unused) {
+static void replication_worker_thread(void *ptr __maybe_unused) {
     CLEANUP_FUNCTION_REGISTER(replication_worker_cleanup) cleanup_ptr = (void *)0x1;
     replication_initialize_workers(false);
 
@@ -1659,8 +1659,6 @@ static void *replication_worker_thread(void *ptr __maybe_unused) {
             sleep_usec(1 * USEC_PER_SEC);
         }
     }
-
-    return NULL;
 }
 
 static void replication_main_cleanup(void *pptr) {
