@@ -13,11 +13,12 @@ import (
 	"net/http"
 	"os"
 	"os/signal"
+	"strings"
 	"sync"
 	"syscall"
 	"time"
 
-	"nhooyr.io/websocket"
+	"github.com/coder/websocket"
 )
 
 // Connection states
@@ -35,10 +36,10 @@ const (
 
 // JSON-RPC 2.0 related structures
 type JsonRpcMessage struct {
-	JsonRpc string      `json:"jsonrpc"`
-	Id      interface{} `json:"id,omitempty"`
-	Method  string      `json:"method,omitempty"`
-	Result  interface{} `json:"result,omitempty"`
+	JsonRpc string        `json:"jsonrpc"`
+	Id      interface{}   `json:"id,omitempty"`
+	Method  string        `json:"method,omitempty"`
+	Result  interface{}   `json:"result,omitempty"`
 	Error   *JsonRpcError `json:"error,omitempty"`
 }
 
@@ -74,16 +75,52 @@ func main() {
 		programName = os.Args[0]
 	}
 
-	if len(os.Args) != 2 {
-		fmt.Fprintf(os.Stderr, "%s: Usage: %s ws://host/path\n", programName, programName)
+	args := os.Args[1:]
+	var targetURL string
+	var bearerToken string
+
+	for len(args) > 0 {
+		arg := args[0]
+		switch {
+		case arg == "--bearer":
+			if len(args) < 2 {
+				fmt.Fprintf(os.Stderr, "%s: Usage: %s [--bearer TOKEN] ws://host/path\n", programName, programName)
+				os.Exit(1)
+			}
+			bearerToken = strings.TrimSpace(args[1])
+			args = args[2:]
+		case strings.HasPrefix(arg, "--bearer="):
+			bearerToken = strings.TrimSpace(strings.TrimPrefix(arg, "--bearer="))
+			args = args[1:]
+		default:
+			if targetURL != "" {
+				fmt.Fprintf(os.Stderr, "%s: Unexpected argument '%s'\n", programName, arg)
+				fmt.Fprintf(os.Stderr, "%s: Usage: %s [--bearer TOKEN] ws://host/path\n", programName, programName)
+				os.Exit(1)
+			}
+			targetURL = arg
+			args = args[1:]
+		}
+	}
+
+	if targetURL == "" {
+		fmt.Fprintf(os.Stderr, "%s: Usage: %s [--bearer TOKEN] ws://host/path\n", programName, programName)
 		os.Exit(1)
 	}
 
+	if bearerToken == "" {
+		bearerToken = strings.TrimSpace(os.Getenv("ND_MCP_BEARER_TOKEN"))
+	}
+
+	if bearerToken != "" {
+		fmt.Fprintf(os.Stderr, "%s: Authorization header enabled for MCP connection\n", programName)
+	}
+
 	// Set up channels for communication
-	stdinCh := make(chan string, 100)      // Buffer stdin messages
-	reconnectCh := make(chan struct{}, 1)  // Signal for immediate reconnection
-	doneCh := make(chan struct{})          // Signal for program termination
-	stdinClosedCh := make(chan struct{})   // Signal that stdin is closed
+	stdinCh := make(chan string, 100)     // Buffer stdin messages
+	reconnectCh := make(chan struct{}, 1) // Signal for immediate reconnection
+	doneCh := make(chan struct{})         // Signal for program termination
+	stdinClosedCh := make(chan struct{})  // Signal that stdin is closed
 
 	// Global state
 	var state int // Connection state
@@ -91,7 +128,7 @@ func main() {
 	var messageQueueMu sync.Mutex
 	messageQueue := []string{}
 	stdinActive := true
-	
+
 	// Pending requests that are waiting for connection to be established
 	var pendingMu sync.Mutex
 	pendingRequests := make(map[interface{}]*PendingRequest)
@@ -136,7 +173,7 @@ func main() {
 			pendingMu.Lock()
 			if req, exists := pendingRequests[msgId]; exists {
 				fmt.Fprintf(os.Stderr, "%s: Connection timeout for request ID %v, sending error response\n", programName, msgId)
-				
+
 				// Create and send error response
 				errorResponse := createJsonRpcError(
 					msgId,
@@ -144,16 +181,16 @@ func main() {
 					"MCP server connection failed",
 					map[string]string{"details": "Could not establish connection to Netdata within timeout period"},
 				)
-				
+
 				fmt.Println(errorResponse)
-				
+
 				// Get the original message
 				originalMessage := req.Message
-				
+
 				// Remove request from pending
 				delete(pendingRequests, msgId)
 				pendingMu.Unlock()
-				
+
 				// Also remove from messageQueue if it exists there
 				messageQueueMu.Lock()
 				for i, msg := range messageQueue {
@@ -191,23 +228,23 @@ func main() {
 	go func() {
 		scanner := bufio.NewScanner(os.Stdin)
 		scannerRunning := true
-		
+
 		// Make scanner buffer larger to handle large messages
 		const maxScanBufferSize = 1024 * 1024 // 1MB
 		buf := make([]byte, maxScanBufferSize)
 		scanner.Buffer(buf, maxScanBufferSize)
-		
+
 		for scannerRunning && scanner.Scan() {
 			text := scanner.Text()
-			
+
 			// Parse for JSON-RPC ID
 			msgId, _ := parseJsonRpcMessage(text)
-			
+
 			// Check connection state
 			stateMu.Lock()
 			currentState := state
 			stateMu.Unlock()
-			
+
 			if currentState != stateConnected && msgId != nil {
 				// Store as pending request with timeout
 				pendingMu.Lock()
@@ -218,13 +255,13 @@ func main() {
 				}
 				pendingRequests[msgId] = req
 				pendingMu.Unlock()
-				
+
 				fmt.Fprintf(os.Stderr, "%s: Received request with ID %v, setting response timeout\n", programName, msgId)
 			}
-			
+
 			// Queue the message
 			stdinCh <- text
-			
+
 			// If we're not connected, trigger immediate reconnection
 			if currentState != stateConnected {
 				select {
@@ -235,14 +272,14 @@ func main() {
 				}
 			}
 		}
-		
+
 		// Check for scanner error
 		if err := scanner.Err(); err != nil {
 			fmt.Fprintf(os.Stderr, "%s: ERROR: stdin read error: %v\n", programName, err)
 		} else {
 			fmt.Fprintf(os.Stderr, "%s: End of stdin\n", programName)
 		}
-		
+
 		// Signal that stdin is closed
 		stdinActive = false
 		close(stdinClosedCh)
@@ -252,10 +289,10 @@ func main() {
 	baseDelay := 1 * time.Second
 	maxDelay := 60 * time.Second
 	attempt := 0
-	
+
 	// Timer for reconnection backoff
 	var timer *time.Timer
-	
+
 	// Main connection loop
 	for {
 		select {
@@ -271,12 +308,12 @@ func main() {
 			if timer != nil {
 				timer.Stop()
 			}
-			
+
 			// Only proceed with immediate reconnection if we're not already connecting/connected
 			stateMu.Lock()
 			currentState := state
 			stateMu.Unlock()
-			
+
 			if currentState == stateDisconnected {
 				// Reset the reconnection timer
 				attempt = 0
@@ -293,17 +330,17 @@ func main() {
 					fmt.Fprintf(os.Stderr, "%s: Stdin closed and disconnected, exiting\n", programName)
 					return
 				}
-				
+
 				delaySeconds := math.Min(float64(maxDelay.Seconds()),
 					float64(baseDelay.Seconds())*math.Pow(2, float64(attempt-1))*(0.5+jitter()))
 				delay := time.Duration(delaySeconds * float64(time.Second))
-				
+
 				fmt.Fprintf(os.Stderr, "%s: Reconnecting in %.1f seconds (attempt %d)...\n",
 					programName, delaySeconds, attempt)
-					
+
 				// Create timer and wait for it to expire, or for signals
 				timer = time.NewTimer(delay)
-				
+
 				select {
 				case <-timer.C:
 					// Timer expired, continue to connection attempt
@@ -330,32 +367,35 @@ func main() {
 
 		// Set up connection context with cancellation
 		ctx, cancel := context.WithCancel(context.Background())
-		
+
 		// Set up connection timeout
 		connectionCtx, connectionCancel := context.WithTimeout(ctx, 15*time.Second)
 		defer connectionCancel()
 
-		fmt.Fprintf(os.Stderr, "%s: Connecting to %s...\n", programName, os.Args[1])
+		fmt.Fprintf(os.Stderr, "%s: Connecting to %s...\n", programName, targetURL)
 
 		// Create a custom header with the WebSocket key
 		header := http.Header{}
 		header.Set("Sec-WebSocket-Key", generateWebSocketKey())
 		header.Set("Sec-WebSocket-Version", "13")
+		if bearerToken != "" {
+			header.Set("Authorization", "Bearer "+bearerToken)
+		}
 
 		// Connect to WebSocket
-		conn, _, err := websocket.Dial(connectionCtx, os.Args[1], &websocket.DialOptions{
+		conn, _, err := websocket.Dial(connectionCtx, targetURL, &websocket.DialOptions{
 			CompressionMode: websocket.CompressionContextTakeover,
 			HTTPHeader:      header,
 		})
-		
+
 		// Connection failed
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "%s: ERROR: websocket connection failed: %v\n", programName, err)
 			cancel()
-			
+
 			// Increment attempt counter and try again
 			attempt++
-			
+
 			// Update state to disconnected
 			stateMu.Lock()
 			state = stateDisconnected
@@ -400,7 +440,7 @@ func main() {
 			messageQueue = nil // Clear the queue
 		}
 		messageQueueMu.Unlock()
-		
+
 		// Memory management: Limit size of pendingRequests to prevent memory leaks
 		pendingMu.Lock()
 		if len(pendingRequests) > 1000 {
@@ -413,10 +453,10 @@ func main() {
 
 		// Signal for connection closure
 		connClosed := make(chan struct{})
-		
+
 		// Create wait group for goroutines
 		var wg sync.WaitGroup
-		
+
 		// Goroutine for handling termination signals during connection
 		wg.Add(1)
 		go func() {
@@ -435,7 +475,7 @@ func main() {
 				return
 			}
 		}()
-		
+
 		// Goroutine for sending messages to websocket
 		wg.Add(1)
 		go func() {
@@ -456,14 +496,14 @@ func main() {
 					if err != nil {
 						// Check if this was a message with ID
 						msgId, _ := parseJsonRpcMessage(msg)
-						
+
 						select {
 						case <-connClosed:
 							// Connection already known to be closed, queue the message
 							messageQueueMu.Lock()
 							messageQueue = append(messageQueue, msg)
 							messageQueueMu.Unlock()
-							
+
 							// If the message had an ID, keep the pending status
 							if msgId != nil {
 								pendingMu.Lock()
@@ -483,7 +523,7 @@ func main() {
 							messageQueueMu.Lock()
 							messageQueue = append(messageQueue, msg)
 							messageQueueMu.Unlock()
-							
+
 							// Same ID handling as above
 							if msgId != nil {
 								pendingMu.Lock()
@@ -523,7 +563,7 @@ func main() {
 		go func() {
 			defer wg.Done()
 			defer close(connClosed)
-			
+
 			for {
 				messageType, message, err := conn.Read(ctx)
 				if err != nil {
@@ -533,10 +573,10 @@ func main() {
 					}
 					return
 				}
-				
+
 				if messageType == websocket.MessageText {
 					fmt.Println(string(message))
-					
+
 					// Check if this is a response to a request with an ID
 					var response JsonRpcMessage
 					if err := json.Unmarshal(message, &response); err == nil && response.JsonRpc == "2.0" && response.Id != nil {
@@ -561,7 +601,7 @@ func main() {
 			defer wg.Done()
 			ticker := time.NewTicker(pingInterval)
 			defer ticker.Stop()
-			
+
 			for {
 				select {
 				case <-ticker.C:
@@ -581,26 +621,26 @@ func main() {
 
 		// Wait for connection closed
 		<-connClosed
-		
+
 		// Update state to disconnected
 		stateMu.Lock()
 		state = stateDisconnected
 		stateMu.Unlock()
-		
+
 		// Clean up
 		cancel()
 		wg.Wait()
-		
+
 		// Don't automatically reconnect if stdin closed and no messages in queue
 		messageQueueMu.Lock()
 		hasMessages := len(messageQueue) > 0
 		messageQueueMu.Unlock()
-		
+
 		if !stdinActive && !hasMessages {
 			fmt.Fprintf(os.Stderr, "%s: Stdin closed and no pending messages, exiting\n", programName)
 			return
 		}
-		
+
 		// Increment attempt counter for next reconnection
 		attempt++
 	}
@@ -613,4 +653,4 @@ func jitter() float64 {
 		return 0.5 // Fall back to 0.5 if there's an error
 	}
 	return float64(n.Int64()) / 1000.0
-}
\ No newline at end of file
+}
